"undefined"===typeof PDFJS&&(("undefined"!==typeof window?window:"undefined"!==typeof global?global:this).PDFJS={});PDFJS.version="1.3.158";PDFJS.build="944d1e6";
(function(){(function(d,g){g(d.pdfjsSharedGlobal={})})(this,function(d){var g="undefined"!==typeof window?window:"undefined"!==typeof global?global:"undefined"!==typeof self?self:this;g.PDFJS||(g.PDFJS={});g.PDFJS.pdfBug=!1;d.globalScope=g;d.isWorker="undefined"===typeof window;d.PDFJS=g.PDFJS});(function(d,g){g(d.pdfjsDisplayDOMUtils={},d.pdfjsSharedGlobal)})(this,function(d,g){var A=g.PDFJS,v=function(){function d(){}var g=["ms","Moz","Webkit","O"],p={};d.getProp=function(d,I){if(1===arguments.length&&
"string"===typeof p[d])return p[d];var I=I||document.documentElement,B=I.style,r,o;if("string"===typeof B[d])return p[d]=d;o=d.charAt(0).toUpperCase()+d.slice(1);for(var e=0,c=g.length;e<c;e++)if(r=g[e]+o,"string"===typeof B[r])return p[d]=r;return p[d]="undefined"};d.setProp=function(d,g,p){d=this.getProp(d);"undefined"!==d&&(g.style[d]=p)};return d}();A.CustomStyle=v;d.CustomStyle=v});(function(d,g){g(d.pdfjsSharedUtil={},d.pdfjsSharedGlobal)})(this,function(d,g){function A(a){c.verbosity>=c.VERBOSITY_LEVELS.warnings&&
console.log("Warning: "+a)}function v(a){A("Deprecated API usage: "+a)}function E(a){c.verbosity>=c.VERBOSITY_LEVELS.errors&&(console.log("Error: "+a),console.log(G()));throw Error(a);}function G(){try{throw Error();}catch(a){return a.stack?a.stack.split("\n").slice(2).join("\n"):""}}function p(a,b){a||E(b)}function l(a,b){if(!a)return!1;var z=/^[a-z][a-z0-9+\-.]*(?=:)/i.exec(a);if(!z)return b;z=z[0].toLowerCase();switch(z){case "http":case "https":case "ftp":case "mailto":case "tel":return!0;default:return!1}}
function I(a,b,z){Object.defineProperty(a,b,{value:z,enumerable:!0,configurable:!0,writable:!1});return z}function B(){c.openExternalLinksInNewWindow&&(v('PDFJS.openExternalLinksInNewWindow, please use "PDFJS.externalLinkTarget = PDFJS.LinkTarget.BLANK" instead.'),c.externalLinkTarget===i.NONE&&(c.externalLinkTarget=i.BLANK),c.openExternalLinksInNewWindow=!1);switch(c.externalLinkTarget){case i.NONE:return!1;case i.SELF:case i.BLANK:case i.PARENT:case i.TOP:return!0}A("PDFJS.externalLinkTarget is invalid: "+
c.externalLinkTarget);c.externalLinkTarget=i.NONE;return!1}function r(a){return"string"!==typeof a?(A("The argument for removeNullCharacters must be a string."),a):a.replace(f,"")}function o(){var a={};a.promise=new Promise(function(b,z){a.resolve=b;a.reject=z});return a}function e(a,b,z){this.sourceName=a;this.targetName=b;this.comObj=z;this.callbackIndex=1;this.postMessageTransfers=!0;var f=this.callbacksCapabilities={},h=this.actionHandler={};this._onComObjOnMessage=function(a){var b=a.data;if(b.targetName===
this.sourceName)if(b.isReply)if(a=b.callbackId,b.callbackId in f){var s=f[a];delete f[a];"error"in b?s.reject(b.error):s.resolve(b.data)}else E("Cannot resolve callback "+a);else if(b.action in h){var F=h[b.action];if(b.callbackId){var M=this.sourceName,K=b.sourceName;Promise.resolve().then(function(){return F[0].call(F[1],b.data)}).then(function(a){z.postMessage({sourceName:M,targetName:K,isReply:!0,callbackId:b.callbackId,data:a})},function(a){a instanceof Error&&(a+="");z.postMessage({sourceName:M,
targetName:K,isReply:!0,callbackId:b.callbackId,error:a})})}else F[0].call(F[1],b.data)}else E("Unknown action from worker: "+b.action)}.bind(this);z.addEventListener("message",this._onComObjOnMessage)}var c=g.PDFJS,y=g.globalScope;c.VERBOSITY_LEVELS={errors:0,warnings:1,infos:5};var C=c.OPS={dependency:1,setLineWidth:2,setLineCap:3,setLineJoin:4,setMiterLimit:5,setDash:6,setRenderingIntent:7,setFlatness:8,setGState:9,save:10,restore:11,transform:12,moveTo:13,lineTo:14,curveTo:15,curveTo2:16,curveTo3:17,
closePath:18,rectangle:19,stroke:20,closeStroke:21,fill:22,eoFill:23,fillStroke:24,eoFillStroke:25,closeFillStroke:26,closeEOFillStroke:27,endPath:28,clip:29,eoClip:30,beginText:31,endText:32,setCharSpacing:33,setWordSpacing:34,setHScale:35,setLeading:36,setFont:37,setTextRenderingMode:38,setTextRise:39,moveText:40,setLeadingMoveText:41,setTextMatrix:42,nextLine:43,showText:44,showSpacedText:45,nextLineShowText:46,nextLineSetSpacingShowText:47,setCharWidth:48,setCharWidthAndBounds:49,setStrokeColorSpace:50,
setFillColorSpace:51,setStrokeColor:52,setStrokeColorN:53,setFillColor:54,setFillColorN:55,setStrokeGray:56,setFillGray:57,setStrokeRGBColor:58,setFillRGBColor:59,setStrokeCMYKColor:60,setFillCMYKColor:61,shadingFill:62,beginInlineImage:63,beginImageData:64,endInlineImage:65,paintXObject:66,markPoint:67,markPointProps:68,beginMarkedContent:69,beginMarkedContentProps:70,endMarkedContent:71,beginCompat:72,endCompat:73,paintFormXObjectBegin:74,paintFormXObjectEnd:75,beginGroup:76,endGroup:77,beginAnnotations:78,
endAnnotations:79,beginAnnotation:80,endAnnotation:81,paintJpegXObject:82,paintImageMaskXObject:83,paintImageMaskXObjectGroup:84,paintImageXObject:85,paintInlineImageXObject:86,paintInlineImageXObjectGroup:87,paintImageXObjectRepeat:88,paintImageMaskXObjectRepeat:89,paintSolidColorImageMask:90,constructPath:91},t=c.UNSUPPORTED_FEATURES={unknown:"unknown",forms:"forms",javaScript:"javaScript",smask:"smask",shadingPattern:"shadingPattern",font:"font"};c.isValidUrl=l;c.shadow=I;var i=c.LinkTarget={NONE:0,
SELF:1,BLANK:2,PARENT:3,TOP:4};c.isExternalLinkTargetSet=B;var k=c.PasswordResponses={NEED_PASSWORD:1,INCORRECT_PASSWORD:2},n=function(){function a(b,z){this.name="PasswordException";this.message=b;this.code=z}a.prototype=Error();return a.constructor=a}();c.PasswordException=n;var m=function(){function a(b,z){this.name="UnknownErrorException";this.message=b;this.details=z}a.prototype=Error();return a.constructor=a}();c.UnknownErrorException=m;var q=function(){function a(b){this.name="InvalidPDFException";
this.message=b}a.prototype=Error();return a.constructor=a}();c.InvalidPDFException=q;var x=function(){function a(b){this.name="MissingPDFException";this.message=b}a.prototype=Error();return a.constructor=a}();c.MissingPDFException=x;var a=function(){function a(b,z){this.name="UnexpectedResponseException";this.message=b;this.status=z}a.prototype=Error();return a.constructor=a}();c.UnexpectedResponseException=a;var b=function(){function a(b){this.message=b}a.prototype=Error();a.prototype.name="NotImplementedException";
return a.constructor=a}(),h=function(){function a(b,z){this.begin=b;this.end=z;this.message="Missing data ["+b+", "+z+")"}a.prototype=Error();a.prototype.name="MissingDataException";return a.constructor=a}(),w=function(){function a(b){this.message=b}a.prototype=Error();a.prototype.name="XRefParseException";return a.constructor=a}(),f=/\x00/g;c.removeNullCharacters=r;Object.defineProperty(c,"isLittleEndian",{configurable:!0,get:function(){var a=c,b;b=new Uint8Array(2);b[0]=1;b=1===(new Uint16Array(b.buffer))[0];
return I(a,"isLittleEndian",b)}});Object.defineProperty(c,"hasCanvasTypedArrays",{configurable:!0,get:function(){var a=c,b;b=document.createElement("canvas");b.width=b.height=1;b="undefined"!==typeof b.getContext("2d").createImageData(1,1).data.buffer;return I(a,"hasCanvasTypedArrays",b)}});var j=function(){function a(f,h){this.buffer=f;this.byteLength=f.length;for(var j=this.length=void 0===h?this.byteLength>>2:h;z<j;)Object.defineProperty(a.prototype,z,b(z)),z++}function b(a){return{get:function(){var b=
this.buffer,z=a<<2;return(b[z]|b[z+1]<<8|b[z+2]<<16|b[z+3]<<24)>>>0},set:function(b){var z=this.buffer,f=a<<2;z[f]=b&255;z[f+1]=b>>8&255;z[f+2]=b>>16&255;z[f+3]=b>>>24&255}}}a.prototype=Object.create(null);var z=0;return a}();d.Uint32ArrayView=j;var u=c.Util=function(){function a(){}var b=["rgb(",0,",",0,",",0,")"];a.makeCssRgb=function(a,f,h){b[1]=a;b[3]=f;b[5]=h;return b.join("")};a.transform=function(a,b){return[a[0]*b[0]+a[2]*b[1],a[1]*b[0]+a[3]*b[1],a[0]*b[2]+a[2]*b[3],a[1]*b[2]+a[3]*b[3],a[0]*
b[4]+a[2]*b[5]+a[4],a[1]*b[4]+a[3]*b[5]+a[5]]};a.applyTransform=function(a,b){return[a[0]*b[0]+a[1]*b[2]+b[4],a[0]*b[1]+a[1]*b[3]+b[5]]};a.applyInverseTransform=function(a,b){var f=b[0]*b[3]-b[1]*b[2];return[(a[0]*b[3]-a[1]*b[2]+b[2]*b[5]-b[4]*b[3])/f,(-a[0]*b[1]+a[1]*b[0]+b[4]*b[1]-b[5]*b[0])/f]};a.getAxialAlignedBoundingBox=function(b,f){var h=a.applyTransform(b,f),j=a.applyTransform(b.slice(2,4),f),c=a.applyTransform([b[0],b[3]],f),s=a.applyTransform([b[2],b[1]],f);return[Math.min(h[0],j[0],c[0],
s[0]),Math.min(h[1],j[1],c[1],s[1]),Math.max(h[0],j[0],c[0],s[0]),Math.max(h[1],j[1],c[1],s[1])]};a.inverseTransform=function(a){var b=a[0]*a[3]-a[1]*a[2];return[a[3]/b,-a[1]/b,-a[2]/b,a[0]/b,(a[2]*a[5]-a[4]*a[3])/b,(a[4]*a[1]-a[5]*a[0])/b]};a.apply3dTransform=function(a,b){return[a[0]*b[0]+a[1]*b[1]+a[2]*b[2],a[3]*b[0]+a[4]*b[1]+a[5]*b[2],a[6]*b[0]+a[7]*b[1]+a[8]*b[2]]};a.singularValueDecompose2dScale=function(a){var b=[a[0],a[2],a[1],a[3]],f=a[0]*b[0]+a[1]*b[2],h=a[2]*b[1]+a[3]*b[3],j=(f+h)/2,a=
Math.sqrt((f+h)*(f+h)-4*(f*h-(a[2]*b[0]+a[3]*b[2])*(a[0]*b[1]+a[1]*b[3])))/2,b=j-a||1;return[Math.sqrt(j+a||1),Math.sqrt(b)]};a.normalizeRect=function(a){var b=a.slice(0);a[0]>a[2]&&(b[0]=a[2],b[2]=a[0]);a[1]>a[3]&&(b[1]=a[3],b[3]=a[1]);return b};a.intersect=function(b,f){function h(a,b){return a-b}var j=[b[0],b[2],f[0],f[2]].sort(h),c=[b[1],b[3],f[1],f[3]].sort(h),s=[],b=a.normalizeRect(b),f=a.normalizeRect(f);if(j[0]===b[0]&&j[1]===f[0]||j[0]===f[0]&&j[1]===b[0])s[0]=j[1],s[2]=j[2];else return!1;
if(c[0]===b[1]&&c[1]===f[1]||c[0]===f[1]&&c[1]===b[1])s[1]=c[1],s[3]=c[2];else return!1;return s};a.sign=function(a){return 0>a?-1:1};a.appendToArray=function(a,b){Array.prototype.push.apply(a,b)};a.prependToArray=function(a,b){Array.prototype.unshift.apply(a,b)};a.extendObj=function(a,b){for(var f in b)a[f]=b[f]};a.getInheritableProperty=function(a,b){for(;a&&!a.has(b);)a=a.get("Parent");return!a?null:a.get(b)};a.inherit=function(a,b,f){a.prototype=Object.create(b.prototype);a.prototype.constructor=
a;for(var h in f)a.prototype[h]=f[h]};a.loadScript=function(a,b){var f=document.createElement("script"),h=!1;f.setAttribute("src",a);b&&(f.onload=function(){h||b();h=!0});document.getElementsByTagName("head")[0].appendChild(f)};return a}();c.PageViewport=function(){function a(b,f,h,j,c,M){this.viewBox=b;this.scale=f;this.rotation=h;this.offsetX=j;this.offsetY=c;var s=(b[2]+b[0])/2,F=(b[3]+b[1])/2,L,K,J,h=h%360;switch(0>h?h+360:h){case 180:h=-1;K=L=0;J=1;break;case 90:h=0;K=L=1;J=0;break;case 270:h=
0;K=L=-1;J=0;break;default:h=1,K=L=0,J=-1}M&&(K=-K,J=-J);0===h?(j=Math.abs(F-b[1])*f+j,c=Math.abs(s-b[0])*f+c,M=Math.abs(b[3]-b[1])*f,b=Math.abs(b[2]-b[0])*f):(j=Math.abs(s-b[0])*f+j,c=Math.abs(F-b[1])*f+c,M=Math.abs(b[2]-b[0])*f,b=Math.abs(b[3]-b[1])*f);this.transform=[h*f,L*f,K*f,J*f,j-h*f*s-K*f*F,c-L*f*s-J*f*F];this.width=M;this.height=b;this.fontScale=f}a.prototype={clone:function(b){var b=b||{},f="scale"in b?b.scale:this.scale,h="rotation"in b?b.rotation:this.rotation;return new a(this.viewBox.slice(),
f,h,this.offsetX,this.offsetY,b.dontFlip)},convertToViewportPoint:function(a,b){return u.applyTransform([a,b],this.transform)},convertToViewportRectangle:function(a){var b=u.applyTransform([a[0],a[1]],this.transform),a=u.applyTransform([a[2],a[3]],this.transform);return[b[0],b[1],a[0],a[1]]},convertToPdfPoint:function(a,b){return u.applyInverseTransform([a,b],this.transform)}};return a}();var H=[0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,728,711,710,729,733,731,730,732,0,0,0,0,0,0,0,0,0,0,0,
0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8226,8224,8225,8230,8212,8211,402,8260,8249,8250,8722,8240,8222,8220,8221,8216,8217,8218,8482,64257,64258,321,338,352,376,381,305,322,339,353,382,0,8364];c.createPromiseCapability=o;(function(){function a(f){this._status=b;this._handlers=[];try{f.call(this,this._resolve.bind(this),this._reject.bind(this))}catch(h){this._reject(h)}}
if(y.Promise)"function"!==typeof y.Promise.all&&(y.Promise.all=function(a){var b=0,f=[],s,F,h=new y.Promise(function(a,b){s=a;F=b});a.forEach(function(a,J){b++;a.then(function(a){f[J]=a;b--;0===b&&s(f)},F)});0===b&&s(f);return h}),"function"!==typeof y.Promise.resolve&&(y.Promise.resolve=function(a){return new y.Promise(function(b){b(a)})}),"function"!==typeof y.Promise.reject&&(y.Promise.reject=function(a){return new y.Promise(function(b,f){f(a)})}),"function"!==typeof y.Promise.prototype.catch&&
(y.Promise.prototype.catch=function(a){return y.Promise.prototype.then(void 0,a)});else{var b=0,f=2,h={handlers:[],running:!1,unhandledRejections:[],pendingRejectionCheck:!1,scheduleHandlers:function(a){a._status!==b&&(this.handlers=this.handlers.concat(a._handlers),a._handlers=[],this.running||(this.running=!0,setTimeout(this.runHandlers.bind(this),0)))},runHandlers:function(){for(var a=Date.now()+1;0<this.handlers.length;){var b=this.handlers.shift(),h=b.thisPromise._status,s=b.thisPromise._value;
try{1===h?"function"===typeof b.onResolve&&(s=b.onResolve(s)):"function"===typeof b.onReject&&(s=b.onReject(s),h=1,b.thisPromise._unhandledRejection&&this.removeUnhandeledRejection(b.thisPromise))}catch(F){h=f,s=F}b.nextPromise._updateStatus(h,s);if(Date.now()>=a)break}0<this.handlers.length?setTimeout(this.runHandlers.bind(this),0):this.running=!1},addUnhandledRejection:function(a){this.unhandledRejections.push({promise:a,time:Date.now()});this.scheduleRejectionCheck()},removeUnhandeledRejection:function(a){a._unhandledRejection=
!1;for(var b=0;b<this.unhandledRejections.length;b++)this.unhandledRejections[b].promise===a&&(this.unhandledRejections.splice(b),b--)},scheduleRejectionCheck:function(){this.pendingRejectionCheck||(this.pendingRejectionCheck=!0,setTimeout(function(){this.pendingRejectionCheck=!1;for(var a=Date.now(),b=0;b<this.unhandledRejections.length;b++)if(500<a-this.unhandledRejections[b].time){var f=this.unhandledRejections[b].promise._value,s="Unhandled rejection: "+f;f.stack&&(s+="\n"+f.stack);A(s);this.unhandledRejections.splice(b);
b--}this.unhandledRejections.length&&this.scheduleRejectionCheck()}.bind(this),500))}};a.all=function(b){function h(a){F._status!==f&&(K=[],s(a))}var j,s,F=new a(function(a,b){j=a;s=b}),L=b.length,K=[];if(0===L)return j(K),F;for(var J=0,c=b.length;J<c;++J){var N=b[J],e=function(a){return function(b){F._status!==f&&(K[a]=b,L--,0===L&&j(K))}}(J);a.isPromise(N)?N.then(e,h):e(N)}return F};a.isPromise=function(a){return a&&"function"===typeof a.then};a.resolve=function(b){return new a(function(a){a(b)})};
a.reject=function(b){return new a(function(a,f){f(b)})};a.prototype={_status:null,_value:null,_handlers:null,_unhandledRejection:null,_updateStatus:function(b,j){1===this._status||this._status===f||(1===b&&a.isPromise(j)?j.then(this._updateStatus.bind(this,1),this._updateStatus.bind(this,f)):(this._status=b,this._value=j,b===f&&0===this._handlers.length&&(this._unhandledRejection=!0,h.addUnhandledRejection(this)),h.scheduleHandlers(this)))},_resolve:function(a){this._updateStatus(1,a)},_reject:function(a){this._updateStatus(f,
a)},then:function(b,f){var j=new a(function(a,b){this.resolve=a;this.reject=b});this._handlers.push({thisPromise:this,onResolve:b,onReject:f,nextPromise:j});h.scheduleHandlers(this);return j},"catch":function(a){return this.then(void 0,a)}};y.Promise=a}})();j=function(){function a(){this.started={};this.times=[];this.enabled=!0}a.prototype={time:function(a){this.enabled&&(a in this.started&&A("Timer is already running for "+a),this.started[a]=Date.now())},timeEnd:function(a){this.enabled&&(a in this.started||
A("Timer has not been started for "+a),this.times.push({name:a,start:this.started[a],end:Date.now()}),delete this.started[a])},toString:function(){var a,b,f=this.times,h="",j=0;for(a=0,b=f.length;a<b;++a){var c=f[a].name;c.length>j&&(j=c.length)}for(a=0,b=f.length;a<b;++a){for(var s=f[a],c=s.end-s.start,s=s.name;s.length<j;)s+=" ";h+=s+" "+c+"ms\n"}return h}};return a}();c.createBlob=function(a,b){if("undefined"!==typeof Blob)return new Blob([a],{type:b});var f=new MozBlobBuilder;f.append(a);return f.getBlob(b)};
c.createObjectURL=function(){return function(a,b){if(!c.disableCreateObjectURL&&"undefined"!==typeof URL&&URL.createObjectURL){var f=c.createBlob(a,b);return URL.createObjectURL(f)}for(var f="data:"+b+";base64,",h=0,j=a.length;h<j;h+=3)var e=a[h]&255,x=a[h+1]&255,s=a[h+2]&255,f=f+("ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/="[e>>2]+"ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/="[(e&3)<<4|x>>4]+"ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/="[h+
1<j?(x&15)<<2|s>>6:64]+"ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/="[h+2<j?s&63:64]);return f}}();e.prototype={on:function(a,b,f){var h=this.actionHandler;h[a]&&E('There is already an actionName called "'+a+'"');h[a]=[b,f]},send:function(a,b,f){this.postMessage({sourceName:this.sourceName,targetName:this.targetName,action:a,data:b},f)},sendWithPromise:function(a,b,f){var h=this.callbackIndex++,a={sourceName:this.sourceName,targetName:this.targetName,action:a,data:b,callbackId:h},
b=o();this.callbacksCapabilities[h]=b;try{this.postMessage(a,f)}catch(j){b.reject(j)}return b.promise},postMessage:function(a,b){b&&this.postMessageTransfers?this.comObj.postMessage(a,b):this.comObj.postMessage(a)},destroy:function(){this.comObj.removeEventListener("message",this._onComObjOnMessage)}};d.FONT_IDENTITY_MATRIX=[0.001,0,0,0.001,0,0];d.IDENTITY_MATRIX=[1,0,0,1,0,0];d.OPS=C;d.UNSUPPORTED_FEATURES=t;d.AnnotationBorderStyleType={SOLID:1,DASHED:2,BEVELED:3,INSET:4,UNDERLINE:5};d.AnnotationFlag=
{INVISIBLE:1,HIDDEN:2,PRINT:4,NOZOOM:8,NOROTATE:16,NOVIEW:32,READONLY:64,LOCKED:128,TOGGLENOVIEW:256,LOCKEDCONTENTS:512};d.AnnotationType={TEXT:1,LINK:2,FREETEXT:3,LINE:4,SQUARE:5,CIRCLE:6,POLYGON:7,POLYLINE:8,HIGHLIGHT:9,UNDERLINE:10,SQUIGGLY:11,STRIKEOUT:12,STAMP:13,CARET:14,INK:15,POPUP:16,FILEATTACHMENT:17,SOUND:18,MOVIE:19,WIDGET:20,SCREEN:21,PRINTERMARK:22,TRAPNET:23,WATERMARK:24,THREED:25,REDACT:26};d.FontType={UNKNOWN:0,TYPE1:1,TYPE1C:2,CIDFONTTYPE0:3,CIDFONTTYPE0C:4,TRUETYPE:5,CIDFONTTYPE2:6,
TYPE3:7,OPENTYPE:8,TYPE0:9,MMTYPE1:10};d.ImageKind={GRAYSCALE_1BPP:1,RGB_24BPP:2,RGBA_32BPP:3};d.InvalidPDFException=q;d.LinkTarget=i;d.LinkTargetStringMap=["","_self","_blank","_parent","_top"];d.MessageHandler=e;d.MissingDataException=h;d.MissingPDFException=x;d.NotImplementedException=b;d.PasswordException=n;d.PasswordResponses=k;d.StatTimer=j;d.StreamType={UNKNOWN:0,FLATE:1,LZW:2,DCT:3,JPX:4,JBIG:5,A85:6,AHX:7,CCF:8,RL:9};d.TextRenderingMode={FILL:0,STROKE:1,FILL_STROKE:2,INVISIBLE:3,FILL_ADD_TO_PATH:4,
STROKE_ADD_TO_PATH:5,FILL_STROKE_ADD_TO_PATH:6,ADD_TO_PATH:7,FILL_STROKE_MASK:3,ADD_TO_PATH_FLAG:4};d.UnexpectedResponseException=a;d.UnknownErrorException=m;d.Util=u;d.XRefParseException=w;d.assert=p;d.bytesToString=function(a){p(null!==a&&"object"===typeof a&&void 0!==a.length,"Invalid argument for bytesToString");var b=a.length;if(8192>b)return String.fromCharCode.apply(null,a);for(var f=[],h=0;h<b;h+=8192){var j=Math.min(h+8192,b),j=a.subarray(h,j);f.push(String.fromCharCode.apply(null,j))}return f.join("")};
d.combineUrl=function(a,b){if(!b)return a;if(/^[a-z][a-z0-9+\-.]*:/i.test(b))return b;var f;if("/"===b.charAt(0))return f=a.indexOf("://"),"/"===b.charAt(1)?++f:f=a.indexOf("/",f+3),a.substring(0,f)+b;var h=a.length;f=a.lastIndexOf("#");h=0<=f?f:h;f=a.lastIndexOf("?",h);f=a.lastIndexOf("/",0<=f?f:h);return a.substring(0,f+1)+b};d.createPromiseCapability=o;d.deprecated=v;d.error=E;d.info=function(a){c.verbosity>=c.VERBOSITY_LEVELS.infos&&console.log("Info: "+a)};d.isArray=function(a){return a instanceof
Array};d.isArrayBuffer=function(a){return"object"===typeof a&&null!==a&&void 0!==a.byteLength};d.isBool=function(a){return"boolean"===typeof a};d.isEmptyObj=function(a){for(var b in a)return!1;return!0};d.isExternalLinkTargetSet=B;d.isInt=function(a){return"number"===typeof a&&(a|0)===a};d.isNum=function(a){return"number"===typeof a};d.isString=function(a){return"string"===typeof a};d.isValidUrl=l;d.loadJpegStream=function(a,b,f){var h=new Image;h.onload=function(){f.resolve(a,h)};h.onerror=function(){f.resolve(a,
null);A("Error during JPEG image loading")};h.src=b};d.log2=function(a){for(var b=1,f=0;a>b;)b<<=1,f++;return f};d.readInt8=function(a,b){return a[b]<<24>>24};d.readUint16=function(a,b){return a[b]<<8|a[b+1]};d.readUint32=function(a,b){return(a[b]<<24|a[b+1]<<16|a[b+2]<<8|a[b+3])>>>0};d.removeNullCharacters=r;d.shadow=I;d.string32=function(a){return String.fromCharCode(a>>24&255,a>>16&255,a>>8&255,a&255)};d.stringToBytes=function(a){p("string"===typeof a,"Invalid argument for stringToBytes");for(var b=
a.length,f=new Uint8Array(b),h=0;h<b;++h)f[h]=a.charCodeAt(h)&255;return f};d.stringToPDFString=function(a){var b,f=a.length,h=[];if("\u00fe"===a[0]&&"\u00ff"===a[1])for(b=2;b<f;b+=2)h.push(String.fromCharCode(a.charCodeAt(b)<<8|a.charCodeAt(b+1)));else for(b=0;b<f;++b){var j=H[a.charCodeAt(b)];h.push(j?String.fromCharCode(j):a.charAt(b))}return h.join("")};d.stringToUTF8String=function(a){return decodeURIComponent(escape(a))};d.utf8StringToString=function(a){return unescape(encodeURIComponent(a))};
d.warn=A});(function(d,g){g(d.pdfjsDisplayAnnotationLayer={},d.pdfjsSharedUtil,d.pdfjsDisplayDOMUtils)})(this,function(d,g,A){function v(){}var E=g.AnnotationBorderStyleType,G=g.AnnotationType,p=g.Util,l=g.isExternalLinkTargetSet,I=g.LinkTargetStringMap,B=g.removeNullCharacters,r=g.warn,o=A.CustomStyle;v.prototype={create:function(e){var a=e.data.annotationType;switch(a){case G.LINK:return new c(e);case G.TEXT:return new y(e);case G.WIDGET:return new C(e);case G.POPUP:return new t(e);case G.HIGHLIGHT:return new k(e);
case G.UNDERLINE:return new n(e);case G.SQUIGGLY:return new m(e);case G.STRIKEOUT:return new q(e);default:throw Error('Unimplemented annotation type "'+a+'"');}}};var e=function(){function c(a){this.data=a.data;this.layer=a.layer;this.page=a.page;this.viewport=a.viewport;this.linkService=a.linkService;this.container=this._createContainer()}c.prototype={_createContainer:function(){var a=this.data,b=this.page,h=this.viewport,c=document.createElement("section"),f=a.rect[2]-a.rect[0],j=a.rect[3]-a.rect[1];
c.setAttribute("data-annotation-id",a.id);b=p.normalizeRect([a.rect[0],b.view[3]-a.rect[1]+b.view[1],a.rect[2],b.view[3]-a.rect[3]+b.view[1]]);o.setProp("transform",c,"matrix("+h.transform.join(",")+")");o.setProp("transformOrigin",c,-b[0]+"px "+-b[1]+"px");if(0<a.borderStyle.width){c.style.borderWidth=a.borderStyle.width+"px";a.borderStyle.style!==E.UNDERLINE&&(f-=2*a.borderStyle.width,j-=2*a.borderStyle.width);var h=a.borderStyle.horizontalCornerRadius,e=a.borderStyle.verticalCornerRadius;(0<h||
0<e)&&o.setProp("borderRadius",c,h+"px / "+e+"px");switch(a.borderStyle.style){case E.SOLID:c.style.borderStyle="solid";break;case E.DASHED:c.style.borderStyle="dashed";break;case E.BEVELED:r("Unimplemented border style: beveled");break;case E.INSET:r("Unimplemented border style: inset");break;case E.UNDERLINE:c.style.borderBottomStyle="solid"}a.color?c.style.borderColor=p.makeCssRgb(a.color[0]|0,a.color[1]|0,a.color[2]|0):c.style.borderWidth=0}c.style.left=b[0]+"px";c.style.top=b[1]+"px";c.style.width=
f+"px";c.style.height=j+"px";return c},render:function(){throw Error("Abstract method AnnotationElement.render called");}};return c}(),c=function(){function c(a){e.call(this,a)}p.inherit(c,e,{render:function(){this.container.className="linkAnnotation";var a=document.createElement("a");a.href=a.title=this.data.url?B(this.data.url):"";this.data.url&&l()&&(a.target=I[PDFJS.externalLinkTarget]);this.data.url&&(a.rel=PDFJS.externalLinkRel);this.data.url||(this.data.action?this._bindNamedAction(a,this.data.action):
this._bindLink(a,"dest"in this.data?this.data.dest:null));this.container.appendChild(a);return this.container},_bindLink:function(a,b){var h=this;a.href=this.linkService.getDestinationHash(b);a.onclick=function(){b&&h.linkService.navigateTo(b);return!1};b&&(a.className="internalLink")},_bindNamedAction:function(a,b){var h=this;a.href=this.linkService.getAnchorUrl("");a.onclick=function(){h.linkService.executeNamedAction(b);return!1};a.className="internalLink"}});return c}(),y=function(){function c(a){e.call(this,
a)}p.inherit(c,e,{render:function(){this.container.className="textAnnotation";var a=document.createElement("img");a.style.height=this.container.style.height;a.style.width=this.container.style.width;a.src=PDFJS.imageResourcesPath+"annotation-"+this.data.name.toLowerCase()+".svg";a.alt="[{{type}} Annotation]";a.dataset.l10nId="text_annotation_type";a.dataset.l10nArgs=JSON.stringify({type:this.data.name});if(!this.data.hasPopup){var b=(new i({container:this.container,trigger:a,color:this.data.color,
title:this.data.title,contents:this.data.contents,hideWrapper:!0})).render();b.style.left=a.style.width;this.container.appendChild(b)}this.container.appendChild(a);return this.container}});return c}(),C=function(){function c(a){e.call(this,a)}p.inherit(c,e,{render:function(){var a=document.createElement("div");a.textContent=this.data.fieldValue;a.style.textAlign=["left","center","right"][this.data.textAlignment];a.style.verticalAlign="middle";a.style.display="table-cell";var b=this.data.fontRefName?
this.page.commonObjs.getData(this.data.fontRefName):null;this._setTextStyle(a,b);this.container.appendChild(a);return this.container},_setTextStyle:function(a,b){var h=a.style;h.fontSize=this.data.fontSize+"px";h.direction=0>this.data.fontDirection?"rtl":"ltr";b&&(h.fontWeight=b.black?b.bold?"900":"bold":b.bold?"bold":"normal",h.fontStyle=b.italic?"italic":"normal",h.fontFamily=(b.loadedName?'"'+b.loadedName+'", ':"")+(b.fallbackName||"Helvetica, sans-serif"))}});return c}(),t=function(){function c(a){e.call(this,
a)}p.inherit(c,e,{render:function(){this.container.className="popupAnnotation";var a=this.layer.querySelector('[data-annotation-id="'+this.data.parentId+'"]');if(!a)return this.container;var b=new i({container:this.container,trigger:a,color:this.data.color,title:this.data.title,contents:this.data.contents}),h=parseFloat(a.style.left),c=parseFloat(a.style.width);o.setProp("transformOrigin",this.container,-(h+c)+"px -"+a.style.top);this.container.style.left=h+c+"px";this.container.appendChild(b.render());
return this.container}});return c}(),i=function(){function c(a){this.container=a.container;this.trigger=a.trigger;this.color=a.color;this.title=a.title;this.contents=a.contents;this.hideWrapper=a.hideWrapper||!1;this.pinned=!1}c.prototype={render:function(){var a=document.createElement("div");a.className="popupWrapper";this.hideElement=this.hideWrapper?a:this.container;this.hideElement.setAttribute("hidden",!0);var b=document.createElement("div");b.className="popup";var h=this.color;h&&(b.style.backgroundColor=
p.makeCssRgb(0.7*(255-h[0])+h[0]|0,0.7*(255-h[1])+h[1]|0,0.7*(255-h[2])+h[2]|0));var h=this._formatContents(this.contents),c=document.createElement("h1");c.textContent=this.title;this.trigger.addEventListener("click",this._toggle.bind(this));this.trigger.addEventListener("mouseover",this._show.bind(this,!1));this.trigger.addEventListener("mouseout",this._hide.bind(this,!1));b.addEventListener("click",this._hide.bind(this,!0));b.appendChild(c);b.appendChild(h);a.appendChild(b);return a},_formatContents:function(a){for(var b=
document.createElement("p"),a=a.split(/(?:\r\n?|\n)/),h=0,c=a.length;h<c;++h)b.appendChild(document.createTextNode(a[h])),h<c-1&&b.appendChild(document.createElement("br"));return b},_toggle:function(){this.pinned?this._hide(!0):this._show(!0)},_show:function(a){a&&(this.pinned=!0);this.hideElement.hasAttribute("hidden")&&(this.hideElement.removeAttribute("hidden"),this.container.style.zIndex+=1)},_hide:function(a){a&&(this.pinned=!1);!this.hideElement.hasAttribute("hidden")&&!this.pinned&&(this.hideElement.setAttribute("hidden",
!0),this.container.style.zIndex-=1)}};return c}(),k=function(){function c(a){e.call(this,a)}p.inherit(c,e,{render:function(){this.container.className="highlightAnnotation";return this.container}});return c}(),n=function(){function c(a){e.call(this,a)}p.inherit(c,e,{render:function(){this.container.className="underlineAnnotation";return this.container}});return c}(),m=function(){function c(a){e.call(this,a)}p.inherit(c,e,{render:function(){this.container.className="squigglyAnnotation";return this.container}});
return c}(),q=function(){function c(a){e.call(this,a)}p.inherit(c,e,{render:function(){this.container.className="strikeoutAnnotation";return this.container}});return c}(),g=function(){return{render:function(c){for(var a=new v,b=0,h=c.annotations.length;b<h;b++){var e=c.annotations[b];e&&e.hasHtml&&(e=a.create({data:e,layer:c.div,page:c.page,viewport:c.viewport,linkService:c.linkService}),c.div.appendChild(e.render()))}},update:function(c){for(var a=0,b=c.annotations.length;a<b;a++){var h=c.div.querySelector('[data-annotation-id="'+
c.annotations[a].id+'"]');h&&o.setProp("transform",h,"matrix("+c.viewport.transform.join(",")+")")}c.div.removeAttribute("hidden")}}}();PDFJS.AnnotationLayer=g;d.AnnotationLayer=g});(function(d,g){g(d.pdfjsDisplayFontLoader={},d.pdfjsSharedUtil,d.pdfjsSharedGlobal)})(this,function(d,g,A){function v(e){this.docId=e;this.styleElement=null;this.nativeFontFaces=[];this.loadTestFontId=0;this.loadingContext={requests:[],nextRequestId:0}}var E=g.assert,G=g.bytesToString,p=g.string32,l=g.shadow,I=g.warn,
B=A.PDFJS,r=A.globalScope,o=A.isWorker;v.prototype={insertRule:function(e){var c=this.styleElement;c||(c=this.styleElement=document.createElement("style"),c.id="PDFJS_FONT_STYLE_TAG_"+this.docId,document.documentElement.getElementsByTagName("head")[0].appendChild(c));c=c.sheet;c.insertRule(e,c.cssRules.length)},clear:function(){var e=this.styleElement;e&&(e.parentNode.removeChild(e),e=this.styleElement=null);this.nativeFontFaces.forEach(function(c){document.fonts.delete(c)});this.nativeFontFaces.length=
0},get loadTestFont(){return l(this,"loadTestFont",atob("T1RUTwALAIAAAwAwQ0ZGIDHtZg4AAAOYAAAAgUZGVE1lkzZwAAAEHAAAABxHREVGABQAFQAABDgAAAAeT1MvMlYNYwkAAAEgAAAAYGNtYXABDQLUAAACNAAAAUJoZWFk/xVFDQAAALwAAAA2aGhlYQdkA+oAAAD0AAAAJGhtdHgD6AAAAAAEWAAAAAZtYXhwAAJQAAAAARgAAAAGbmFtZVjmdH4AAAGAAAAAsXBvc3T/hgAzAAADeAAAACAAAQAAAAEAALZRFsRfDzz1AAsD6AAAAADOBOTLAAAAAM4KHDwAAAAAA+gDIQAAAAgAAgAAAAAAAAABAAADIQAAAFoD6AAAAAAD6AABAAAAAAAAAAAAAAAAAAAAAQAAUAAAAgAAAAQD6AH0AAUAAAKKArwAAACMAooCvAAAAeAAMQECAAACAAYJAAAAAAAAAAAAAQAAAAAAAAAAAAAAAFBmRWQAwAAuAC4DIP84AFoDIQAAAAAAAQAAAAAAAAAAACAAIAABAAAADgCuAAEAAAAAAAAAAQAAAAEAAAAAAAEAAQAAAAEAAAAAAAIAAQAAAAEAAAAAAAMAAQAAAAEAAAAAAAQAAQAAAAEAAAAAAAUAAQAAAAEAAAAAAAYAAQAAAAMAAQQJAAAAAgABAAMAAQQJAAEAAgABAAMAAQQJAAIAAgABAAMAAQQJAAMAAgABAAMAAQQJAAQAAgABAAMAAQQJAAUAAgABAAMAAQQJAAYAAgABWABYAAAAAAAAAwAAAAMAAAAcAAEAAAAAADwAAwABAAAAHAAEACAAAAAEAAQAAQAAAC7//wAAAC7////TAAEAAAAAAAABBgAAAQAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAEAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAMAAAAAAAD/gwAyAAAAAQAAAAAAAAAAAAAAAAAAAAABAAQEAAEBAQJYAAEBASH4DwD4GwHEAvgcA/gXBIwMAYuL+nz5tQXkD5j3CBLnEQACAQEBIVhYWFhYWFhYWFhYWFhYWFhYWFhYWFhYWFhYWFhYWFhYAAABAQAADwACAQEEE/t3Dov6fAH6fAT+fPp8+nwHDosMCvm1Cvm1DAz6fBQAAAAAAAABAAAAAMmJbzEAAAAAzgTjFQAAAADOBOQpAAEAAAAAAAAADAAUAAQAAAABAAAAAgABAAAAAAAAAAAD6AAAAAAAAA=="))},
addNativeFontFace:function(e){this.nativeFontFaces.push(e);document.fonts.add(e)},bind:function(e,c){E(!o,"bind() shall be called from main thread");for(var d=[],g=[],t=[],i=function(a){return a.loaded.catch(function(b){I('Failed to load font "'+a.family+'": '+b)})},k=0,n=e.length;k<n;k++){var m=e[k];if(!(m.attached||!1===m.loading))if(m.attached=!0,v.isFontLoadingAPISupported){if(m=m.createNativeFontFace())this.addNativeFontFace(m),t.push(i(m))}else{var q=m.createFontFaceRule();q&&(this.insertRule(q),
d.push(q),g.push(m))}}var x=this.queueLoadingCallback(c);v.isFontLoadingAPISupported?Promise.all(t).then(function(){x.complete()}):0<d.length&&!v.isSyncFontLoadingSupported?this.prepareFontLoadEvent(d,g,x):x.complete()},queueLoadingCallback:function(e){var c=this.loadingContext,d={id:"pdfjs-font-loading-"+c.nextRequestId++,complete:function(){E(!d.end,"completeRequest() cannot be called twice");for(d.end=Date.now();0<c.requests.length&&c.requests[0].end;){var e=c.requests.shift();setTimeout(e.callback,
0)}},callback:e,started:Date.now()};c.requests.push(d);return d},prepareFontLoadEvent:function(e,c,d){function g(a,b){return a.charCodeAt(b)<<24|a.charCodeAt(b+1)<<16|a.charCodeAt(b+2)<<8|a.charCodeAt(b+3)&255}function t(a,b,f,c){var e=a.substr(0,b),a=a.substr(b+f);return e+c+a}function i(a,b){q++;30<q?(I("Load test font never loaded."),b()):(m.font="30px "+a,m.fillText(".",0,20),0<m.getImageData(0,0,1,1).data[3]?b():setTimeout(i.bind(null,a,b)))}var k,n,e=document.createElement("canvas");e.width=
1;e.height=1;var m=e.getContext("2d"),q=0,e="lt"+Date.now()+this.loadTestFontId++,x=this.loadTestFont,x=t(x,976,e.length,e),a=g(x,16);for(k=0,n=e.length-3;k<n;k+=4)a=a-1482184792+g(e,k)|0;k<e.length&&(a=a-1482184792+g(e+"XXX",k)|0);x=t(x,16,4,p(a));k="url(data:font/opentype;base64,"+btoa(x)+");";this.insertRule('@font-face { font-family:"'+e+'";src:'+k+"}");x=[];for(k=0,n=c.length;k<n;k++)x.push(c[k].loadedName);x.push(e);var b=document.createElement("div");b.setAttribute("style","visibility: hidden;width: 10px; height: 10px;position: absolute; top: 0px; left: 0px;");
for(k=0,n=x.length;k<n;++k)c=document.createElement("span"),c.textContent="Hi",c.style.fontFamily=x[k],b.appendChild(c);document.body.appendChild(b);i(e,function(){document.body.removeChild(b);d.complete()})}};v.isFontLoadingAPISupported=!o&&"undefined"!==typeof document&&!!document.fonts;Object.defineProperty(v,"isSyncFontLoadingSupported",{get:function(){var e=!1,c=window.navigator.userAgent,d=/Mozilla\/5.0.*?rv:(\d+).*? Gecko/.exec(c);d&&14<=d[1]&&(e=!0);"node"===c&&(e=!0);return l(v,"isSyncFontLoadingSupported",
e)},enumerable:!0,configurable:!0});g=function(){function e(c){this.compiledGlyphs={};for(var e in c)this[e]=c[e]}Object.defineProperty(e,"isEvalSupported",{get:function(){var c=!1;if(B.isEvalSupported)try{new Function(""),c=!0}catch(e){}return l(this,"isEvalSupported",c)},enumerable:!0,configurable:!0});e.prototype={createNativeFontFace:function(){if(!this.data)return null;if(B.disableFontFace)return this.disableFontFace=!0,null;var c=new FontFace(this.loadedName,this.data,{});B.pdfBug&&"FontInspector"in
r&&r.FontInspector.enabled&&r.FontInspector.fontAdded(this);return c},createFontFaceRule:function(){if(!this.data)return null;if(B.disableFontFace)return this.disableFontFace=!0,null;var c=G(new Uint8Array(this.data)),e=this.loadedName,c="url(data:"+this.mimetype+";base64,"+window.btoa(c)+");",e='@font-face { font-family:"'+e+'";src:'+c+"}";B.pdfBug&&"FontInspector"in r&&r.FontInspector.enabled&&r.FontInspector.fontAdded(this,c);return e},getPathGenerator:function(c,d){if(!(d in this.compiledGlyphs)){var g=
c.get(this.loadedName+"_path_"+d),t,i,k;if(e.isEvalSupported){var n,m="";for(i=0,k=g.length;i<k;i++)t=g[i],n=void 0!==t.args?t.args.join(","):"",m+="c."+t.cmd+"("+n+");\n";this.compiledGlyphs[d]=new Function("c","size",m)}else this.compiledGlyphs[d]=function(c,e){for(i=0,k=g.length;i<k;i++)t=g[i],"scale"===t.cmd&&(t.args=[e,-e]),c[t.cmd].apply(c,t.args)}}return this.compiledGlyphs[d]}};return e}();d.FontFaceObject=g;d.FontLoader=v});(function(d,g){g(d.pdfjsDisplayMetadata={},d.pdfjsSharedUtil)})(this,
function(d,g){var A=g.error,v=PDFJS.Metadata=function(){function d(g){return g.replace(/>\\376\\377([^<]+)/g,function(d,g){for(var p=g.replace(/\\([0-3])([0-7])([0-7])/g,function(c,e,d,t){return String.fromCharCode(64*e+8*d+1*t)}),r="",o=0;o<p.length;o+=2)var e=256*p.charCodeAt(o)+p.charCodeAt(o+1),r=r+("&#x"+(65536+e).toString(16).substring(1)+";");return">"+r})}function g(p){"string"===typeof p?(p=d(p),p=(new DOMParser).parseFromString(p,"application/xml")):p instanceof Document||A("Metadata: Invalid metadata object");
this.metaDocument=p;this.metadata={};this.parse()}g.prototype={parse:function(){var d=this.metaDocument.documentElement;if("rdf:rdf"!==d.nodeName.toLowerCase())for(d=d.firstChild;d&&"rdf:rdf"!==d.nodeName.toLowerCase();)d=d.nextSibling;var g=d?d.nodeName.toLowerCase():null;if(d&&"rdf:rdf"===g&&d.hasChildNodes()){var d=d.childNodes,v,B,r,o,e,c;for(r=0,e=d.length;r<e;r++)if(g=d[r],"rdf:description"===g.nodeName.toLowerCase())for(o=0,c=g.childNodes.length;o<c;o++)"#text"!==g.childNodes[o].nodeName.toLowerCase()&&
(v=g.childNodes[o],B=v.nodeName.toLowerCase(),this.metadata[B]=v.textContent.trim())}},get:function(d){return this.metadata[d]||null},has:function(d){return"undefined"!==typeof this.metadata[d]}};return g}();d.Metadata=v});(function(d,g){g(d.pdfjsDisplaySVG={},d.pdfjsSharedUtil)})(this,function(d,g){var A,v,E=g.FONT_IDENTITY_MATRIX,G=g.IDENTITY_MATRIX,p=g.ImageKind,l=g.OPS,I=g.Util,B=g.isNum,r=g.isArray,o=g.warn;A="normal";v="#000000";var e=function(){function c(e,t,a,b){var h=b,g=t.length;a[h]=g>>
24&255;a[h+1]=g>>16&255;a[h+2]=g>>8&255;a[h+3]=g&255;h+=4;a[h]=e.charCodeAt(0)&255;a[h+1]=e.charCodeAt(1)&255;a[h+2]=e.charCodeAt(2)&255;a[h+3]=e.charCodeAt(3)&255;h+=4;a.set(t,h);h+=t.length;e=-1;for(b+=4;b<h;b++)e=e>>>8^d[(e^a[b])&255];b=e^-1;a[h]=b>>24&255;a[h+1]=b>>16&255;a[h+2]=b>>8&255;a[h+3]=b&255}for(var e=new Uint8Array([137,80,78,71,13,10,26,10]),d=new Int32Array(256),k=0;256>k;k++){for(var g=k,m=0;8>m;m++)g=g&1?3988292384^g>>1&2147483647:g>>1&2147483647;d[k]=g}return function(d){var i=
void 0===d.kind?p.GRAYSCALE_1BPP:d.kind,a=d.width,b=d.height,h,g,f,j=d.data;switch(i){case p.GRAYSCALE_1BPP:g=0;h=1;f=a+7>>3;break;case p.RGB_24BPP:g=2;h=8;f=3*a;break;case p.RGBA_32BPP:g=6;h=8;f=4*a;break;default:throw Error("invalid format");}var d=new Uint8Array((1+f)*b),u=0,k=0,m;for(m=0;m<b;++m)d[u++]=0,d.set(j.subarray(k,k+f),u),k+=f,u+=f;if(i===p.GRAYSCALE_1BPP)for(m=u=0;m<b;m++){u++;for(i=0;i<f;i++)d[u++]^=255}a=new Uint8Array([a>>24&255,a>>16&255,a>>8&255,a&255,b>>24&255,b>>16&255,b>>8&255,
b&255,h,g,0,0,0]);h=d.length;b=Math.ceil(h/65535);b=new Uint8Array(2+h+5*b+4);i=0;b[i++]=120;b[i++]=156;for(g=0;65535<h;)b[i++]=0,b[i++]=255,b[i++]=255,b[i++]=0,b[i++]=0,b.set(d.subarray(g,g+65535),i),i+=65535,g+=65535,h-=65535;b[i++]=1;b[i++]=h&255;b[i++]=h>>8&255;b[i++]=~h&255;b[i++]=(~h&65535)>>8&255;b.set(d.subarray(g),i);i+=d.length-g;h=1;for(f=g=0;f<d.length;++f)h=(h+(d[f]&255))%65521,g=(g+h)%65521;d=g<<16|h;b[i++]=d>>24&255;b[i++]=d>>16&255;b[i++]=d>>8&255;b[i++]=d&255;d=new Uint8Array(e.length+
36+a.length+b.length);i=0;d.set(e,i);i+=e.length;c("IHDR",a,d,i);i+=12+a.length;c("IDATA",b,d,i);i+=12+b.length;c("IEND",new Uint8Array(0),d,i);return PDFJS.createObjectURL(d,"image/png")}}(),c=function(){function c(){this.fontSizeScale=1;this.fontWeight=A;this.fontSize=0;this.textMatrix=G;this.fontMatrix=E;this.wordSpacing=this.charSpacing=this.lineY=this.lineX=this.y=this.x=this.leading=0;this.textHScale=1;this.textRise=0;this.fillColor=v;this.strokeColor="#000000";this.lineWidth=this.strokeAlpha=
this.fillAlpha=1;this.lineCap=this.lineJoin="";this.miterLimit=0;this.dashArray=[];this.dashPhase=0;this.dependencies=[];this.clipId="";this.pendingClip=!1;this.maskId=""}c.prototype={clone:function(){return Object.create(this)},setCurrentPoint:function(c,e){this.x=c;this.y=e}};return c}(),y=function(){function d(a,b){var c=document.createElementNS("http://www.w3.org/2000/svg","svg:svg");c.setAttributeNS(null,"version","1.1");c.setAttributeNS(null,"width",a+"px");c.setAttributeNS(null,"height",b+
"px");c.setAttributeNS(null,"viewBox","0 0 "+a+" "+b);return c}function g(a){if(a===(a|0))return a.toString();var a=a.toFixed(10),b=a.length-1;if("0"!==a[b])return a;do b--;while("0"===a[b]);return a.substr(0,"."===a[b]?b:b+1)}function i(a){if(0===a[4]&&0===a[5]){if(0===a[1]&&0===a[2])return 1===a[0]&&1===a[3]?"":"scale("+g(a[0])+" "+g(a[3])+")";if(a[0]===a[3]&&a[1]===-a[2])return a=180*Math.acos(a[0])/Math.PI,"rotate("+g(a)+")"}else if(1===a[0]&&0===a[1]&&0===a[2]&&1===a[3])return"translate("+g(a[4])+
" "+g(a[5])+")";return"matrix("+g(a[0])+" "+g(a[1])+" "+g(a[2])+" "+g(a[3])+" "+g(a[4])+" "+g(a[5])+")"}function k(a,b){this.current=new c;this.transformMatrix=G;this.transformStack=[];this.extraStack=[];this.commonObjs=a;this.objs=b;this.embedFonts=this.pendingEOFill=!1;this.embeddedFonts={};this.cssStyle=null}var n=["butt","round","square"],m=["miter","round","bevel"],y=0,x=0;k.prototype={save:function(){this.transformStack.push(this.transformMatrix);var a=this.current;this.extraStack.push(a);this.current=
a.clone()},restore:function(){this.transformMatrix=this.transformStack.pop();this.current=this.extraStack.pop();this.tgrp=document.createElementNS("http://www.w3.org/2000/svg","svg:g");this.tgrp.setAttributeNS(null,"transform",i(this.transformMatrix));this.pgrp.appendChild(this.tgrp)},group:function(a){this.save();this.executeOpTree(a);this.restore()},loadDependencies:function(a){for(var b=a.fnArray,c=b.length,a=a.argsArray,e=this,f=0;f<c;f++)if(l.dependency===b[f])for(var j=a[f],g=0,d=j.length;g<
d;g++){var i=j[g];this.current.dependencies.push("g_"===i.substring(0,2)?new Promise(function(a){e.commonObjs.get(i,a)}):new Promise(function(a){e.objs.get(i,a)}))}return Promise.all(this.current.dependencies)},transform:function(a,b,c,e,f,j){this.transformMatrix=PDFJS.Util.transform(this.transformMatrix,[a,b,c,e,f,j]);this.tgrp=document.createElementNS("http://www.w3.org/2000/svg","svg:g");this.tgrp.setAttributeNS(null,"transform",i(this.transformMatrix))},getSVG:function(a,b){this.svg=d(b.width,
b.height);this.viewport=b;return this.loadDependencies(a).then(function(){this.transformMatrix=G;this.pgrp=document.createElementNS("http://www.w3.org/2000/svg","svg:g");this.pgrp.setAttributeNS(null,"transform",i(b.transform));this.tgrp=document.createElementNS("http://www.w3.org/2000/svg","svg:g");this.tgrp.setAttributeNS(null,"transform",i(this.transformMatrix));this.defs=document.createElementNS("http://www.w3.org/2000/svg","svg:defs");this.pgrp.appendChild(this.defs);this.pgrp.appendChild(this.tgrp);
this.svg.appendChild(this.pgrp);this.executeOpTree(this.convertOpList(a));return this.svg}.bind(this))},convertOpList:function(a){var b=a.argsArray,c=a.fnArray,e=c.length,f=[],a=[],j;for(j in l)f[l[j]]=j;for(j=0;j<e;j++){var g=c[j];a.push({fnId:g,fn:f[g],args:b[j]})}b=[];c=[];e=a.length;for(f=0;f<e;f++)"save"===a[f].fn?(b.push({fnId:92,fn:"group",items:[]}),c.push(b),b=b[b.length-1].items):"restore"===a[f].fn?b=c.pop():b.push(a[f]);return b},executeOpTree:function(a){for(var b=a.length,c=0;c<b;c++){var e=
a[c].fn,f=a[c].args;switch(a[c].fnId|0){case l.beginText:this.beginText();break;case l.setLeading:this.setLeading(f);break;case l.setLeadingMoveText:this.setLeadingMoveText(f[0],f[1]);break;case l.setFont:this.setFont(f);break;case l.showText:this.showText(f[0]);break;case l.showSpacedText:this.showText(f[0]);break;case l.endText:this.endText();break;case l.moveText:this.moveText(f[0],f[1]);break;case l.setCharSpacing:this.setCharSpacing(f[0]);break;case l.setWordSpacing:this.setWordSpacing(f[0]);
break;case l.setHScale:this.setHScale(f[0]);break;case l.setTextMatrix:this.setTextMatrix(f[0],f[1],f[2],f[3],f[4],f[5]);break;case l.setLineWidth:this.setLineWidth(f[0]);break;case l.setLineJoin:this.setLineJoin(f[0]);break;case l.setLineCap:this.setLineCap(f[0]);break;case l.setMiterLimit:this.setMiterLimit(f[0]);break;case l.setFillRGBColor:this.setFillRGBColor(f[0],f[1],f[2]);break;case l.setStrokeRGBColor:this.setStrokeRGBColor(f[0],f[1],f[2]);break;case l.setDash:this.setDash(f[0],f[1]);break;
case l.setGState:this.setGState(f[0]);break;case l.fill:this.fill();break;case l.eoFill:this.eoFill();break;case l.stroke:this.stroke();break;case l.fillStroke:this.fillStroke();break;case l.eoFillStroke:this.eoFillStroke();break;case l.clip:this.clip("nonzero");break;case l.eoClip:this.clip("evenodd");break;case l.paintSolidColorImageMask:this.paintSolidColorImageMask();break;case l.paintJpegXObject:this.paintJpegXObject(f[0],f[1],f[2]);break;case l.paintImageXObject:this.paintImageXObject(f[0]);
break;case l.paintInlineImageXObject:this.paintInlineImageXObject(f[0]);break;case l.paintImageMaskXObject:this.paintImageMaskXObject(f[0]);break;case l.paintFormXObjectBegin:this.paintFormXObjectBegin(f[0],f[1]);break;case l.paintFormXObjectEnd:this.paintFormXObjectEnd();break;case l.closePath:this.closePath();break;case l.closeStroke:this.closeStroke();break;case l.closeFillStroke:this.closeFillStroke();break;case l.nextLine:this.nextLine();break;case l.transform:this.transform(f[0],f[1],f[2],f[3],
f[4],f[5]);break;case l.constructPath:this.constructPath(f[0],f[1]);break;case l.endPath:this.endPath();break;case 92:this.group(a[c].items);break;default:o("Unimplemented method "+e)}}},setWordSpacing:function(a){this.current.wordSpacing=a},setCharSpacing:function(a){this.current.charSpacing=a},nextLine:function(){this.moveText(0,this.current.leading)},setTextMatrix:function(a,b,c,e,f,j){var d=this.current;this.current.textMatrix=this.current.lineMatrix=[a,b,c,e,f,j];this.current.x=this.current.lineX=
0;this.current.y=this.current.lineY=0;d.xcoords=[];d.tspan=document.createElementNS("http://www.w3.org/2000/svg","svg:tspan");d.tspan.setAttributeNS(null,"font-family",d.fontFamily);d.tspan.setAttributeNS(null,"font-size",g(d.fontSize)+"px");d.tspan.setAttributeNS(null,"y",g(-d.y));d.txtElement=document.createElementNS("http://www.w3.org/2000/svg","svg:text");d.txtElement.appendChild(d.tspan)},beginText:function(){this.current.x=this.current.lineX=0;this.current.y=this.current.lineY=0;this.current.textMatrix=
G;this.current.lineMatrix=G;this.current.tspan=document.createElementNS("http://www.w3.org/2000/svg","svg:tspan");this.current.txtElement=document.createElementNS("http://www.w3.org/2000/svg","svg:text");this.current.txtgrp=document.createElementNS("http://www.w3.org/2000/svg","svg:g");this.current.xcoords=[]},moveText:function(a,b){var c=this.current;this.current.x=this.current.lineX+=a;this.current.y=this.current.lineY+=b;c.xcoords=[];c.tspan=document.createElementNS("http://www.w3.org/2000/svg",
"svg:tspan");c.tspan.setAttributeNS(null,"font-family",c.fontFamily);c.tspan.setAttributeNS(null,"font-size",g(c.fontSize)+"px");c.tspan.setAttributeNS(null,"y",g(-c.y))},showText:function(a){var b=this.current,c=b.fontSize;if(0!==c){var e=b.charSpacing,f=b.wordSpacing,j=b.fontDirection,d=b.textHScale*j,k=a.length,m=b.font.vertical,n=c*b.fontMatrix[0],o=0,y;for(y=0;y<k;++y){var C=a[y];if(null===C)o+=j*f;else if(B(C))o+=0.001*-C*c;else{b.xcoords.push(b.x+o*d);var q=C.fontChar,o=o+(C.width*n+e*j);b.tspan.textContent+=
q}}m?b.y-=o*d:b.x+=o*d;b.tspan.setAttributeNS(null,"x",b.xcoords.map(g).join(" "));b.tspan.setAttributeNS(null,"y",g(-b.y));b.tspan.setAttributeNS(null,"font-family",b.fontFamily);b.tspan.setAttributeNS(null,"font-size",g(b.fontSize)+"px");"normal"!==b.fontStyle&&b.tspan.setAttributeNS(null,"font-style",b.fontStyle);b.fontWeight!==A&&b.tspan.setAttributeNS(null,"font-weight",b.fontWeight);b.fillColor!==v&&b.tspan.setAttributeNS(null,"fill",b.fillColor);b.txtElement.setAttributeNS(null,"transform",
i(b.textMatrix)+" scale(1, -1)");b.txtElement.setAttributeNS("http://www.w3.org/XML/1998/namespace","xml:space","preserve");b.txtElement.appendChild(b.tspan);b.txtgrp.appendChild(b.txtElement);this.tgrp.appendChild(b.txtElement)}},setLeadingMoveText:function(a,b){this.setLeading(-b);this.moveText(a,b)},addFontStyle:function(a){this.cssStyle||(this.cssStyle=document.createElementNS("http://www.w3.org/2000/svg","svg:style"),this.cssStyle.setAttributeNS(null,"type","text/css"),this.defs.appendChild(this.cssStyle));
var b=PDFJS.createObjectURL(a.data,a.mimetype);this.cssStyle.textContent+='@font-face { font-family: "'+a.loadedName+'"; src: url('+b+"); }\n"},setFont:function(a){var b=this.current,c=this.commonObjs.get(a[0]),a=a[1];this.current.font=c;this.embedFonts&&c.data&&!this.embeddedFonts[c.loadedName]&&(this.addFontStyle(c),this.embeddedFonts[c.loadedName]=c);b.fontMatrix=c.fontMatrix?c.fontMatrix:E;var e=c.black?c.bold?"bolder":"bold":c.bold?"bold":"normal",f=c.italic?"italic":"normal";0>a?(a=-a,b.fontDirection=
-1):b.fontDirection=1;b.fontSize=a;b.fontFamily=c.loadedName;b.fontWeight=e;b.fontStyle=f;b.tspan=document.createElementNS("http://www.w3.org/2000/svg","svg:tspan");b.tspan.setAttributeNS(null,"y",g(-b.y));b.xcoords=[]},endText:function(){this.current.pendingClip?(this.cgrp.appendChild(this.tgrp),this.pgrp.appendChild(this.cgrp)):this.pgrp.appendChild(this.tgrp);this.tgrp=document.createElementNS("http://www.w3.org/2000/svg","svg:g");this.tgrp.setAttributeNS(null,"transform",i(this.transformMatrix))},
setLineWidth:function(a){this.current.lineWidth=a},setLineCap:function(a){this.current.lineCap=n[a]},setLineJoin:function(a){this.current.lineJoin=m[a]},setMiterLimit:function(a){this.current.miterLimit=a},setStrokeRGBColor:function(a,b,c){this.current.strokeColor=I.makeCssRgb(a,b,c)},setFillRGBColor:function(a,b,c){this.current.fillColor=I.makeCssRgb(a,b,c);this.current.tspan=document.createElementNS("http://www.w3.org/2000/svg","svg:tspan");this.current.xcoords=[]},setDash:function(a,b){this.current.dashArray=
a;this.current.dashPhase=b},constructPath:function(a,b){var c=this.current,e=c.x,f=c.y;c.path=document.createElementNS("http://www.w3.org/2000/svg","svg:path");for(var j=[],d=a.length,i=0,k=0;i<d;i++)switch(a[i]|0){case l.rectangle:var e=b[k++],f=b[k++],m=b[k++],o=b[k++],m=e+m,o=f+o;j.push("M",g(e),g(f),"L",g(m),g(f),"L",g(m),g(o),"L",g(e),g(o),"Z");break;case l.moveTo:e=b[k++];f=b[k++];j.push("M",g(e),g(f));break;case l.lineTo:e=b[k++];f=b[k++];j.push("L",g(e),g(f));break;case l.curveTo:e=b[k+4];
f=b[k+5];j.push("C",g(b[k]),g(b[k+1]),g(b[k+2]),g(b[k+3]),g(e),g(f));k+=6;break;case l.curveTo2:e=b[k+2];f=b[k+3];j.push("C",g(e),g(f),g(b[k]),g(b[k+1]),g(b[k+2]),g(b[k+3]));k+=4;break;case l.curveTo3:e=b[k+2];f=b[k+3];j.push("C",g(b[k]),g(b[k+1]),g(e),g(f),g(e),g(f));k+=4;break;case l.closePath:j.push("Z")}c.path.setAttributeNS(null,"d",j.join(" "));c.path.setAttributeNS(null,"stroke-miterlimit",g(c.miterLimit));c.path.setAttributeNS(null,"stroke-linecap",c.lineCap);c.path.setAttributeNS(null,"stroke-linejoin",
c.lineJoin);c.path.setAttributeNS(null,"stroke-width",g(c.lineWidth)+"px");c.path.setAttributeNS(null,"stroke-dasharray",c.dashArray.map(g).join(" "));c.path.setAttributeNS(null,"stroke-dashoffset",g(c.dashPhase)+"px");c.path.setAttributeNS(null,"fill","none");this.tgrp.appendChild(c.path);c.pendingClip?(this.cgrp.appendChild(this.tgrp),this.pgrp.appendChild(this.cgrp)):this.pgrp.appendChild(this.tgrp);c.element=c.path;c.setCurrentPoint(e,f)},endPath:function(){this.current.pendingClip?(this.cgrp.appendChild(this.tgrp),
this.pgrp.appendChild(this.cgrp)):this.pgrp.appendChild(this.tgrp);this.tgrp=document.createElementNS("http://www.w3.org/2000/svg","svg:g");this.tgrp.setAttributeNS(null,"transform",i(this.transformMatrix))},clip:function(a){var b=this.current;b.clipId="clippath"+y;y++;this.clippath=document.createElementNS("http://www.w3.org/2000/svg","svg:clipPath");this.clippath.setAttributeNS(null,"id",b.clipId);var c=b.element.cloneNode();"evenodd"===a?c.setAttributeNS(null,"clip-rule","evenodd"):c.setAttributeNS(null,
"clip-rule","nonzero");this.clippath.setAttributeNS(null,"transform",i(this.transformMatrix));this.clippath.appendChild(c);this.defs.appendChild(this.clippath);b.pendingClip=!0;this.cgrp=document.createElementNS("http://www.w3.org/2000/svg","svg:g");this.cgrp.setAttributeNS(null,"clip-path","url(#"+b.clipId+")");this.pgrp.appendChild(this.cgrp)},closePath:function(){var a=this.current,b=a.path.getAttributeNS(null,"d");a.path.setAttributeNS(null,"d",b+"Z")},setLeading:function(a){this.current.leading=
-a},setTextRise:function(a){this.current.textRise=a},setHScale:function(a){this.current.textHScale=a/100},setGState:function(a){for(var b=0,c=a.length;b<c;b++){var e=a[b],f=e[1];switch(e[0]){case "LW":this.setLineWidth(f);break;case "LC":this.setLineCap(f);break;case "LJ":this.setLineJoin(f);break;case "ML":this.setMiterLimit(f);break;case "D":this.setDash(f[0],f[1]);break;case "Font":this.setFont(f)}}},fill:function(){var a=this.current;a.element.setAttributeNS(null,"fill",a.fillColor)},stroke:function(){var a=
this.current;a.element.setAttributeNS(null,"stroke",a.strokeColor);a.element.setAttributeNS(null,"fill","none")},eoFill:function(){var a=this.current;a.element.setAttributeNS(null,"fill",a.fillColor);a.element.setAttributeNS(null,"fill-rule","evenodd")},fillStroke:function(){this.stroke();this.fill()},eoFillStroke:function(){this.current.element.setAttributeNS(null,"fill-rule","evenodd");this.fillStroke()},closeStroke:function(){this.closePath();this.stroke()},closeFillStroke:function(){this.closePath();
this.fillStroke()},paintSolidColorImageMask:function(){var a=this.current,b=document.createElementNS("http://www.w3.org/2000/svg","svg:rect");b.setAttributeNS(null,"x","0");b.setAttributeNS(null,"y","0");b.setAttributeNS(null,"width","1px");b.setAttributeNS(null,"height","1px");b.setAttributeNS(null,"fill",a.fillColor);this.tgrp.appendChild(b)},paintJpegXObject:function(a,b,c){var e=this.current,a=this.objs.get(a),f=document.createElementNS("http://www.w3.org/2000/svg","svg:image");f.setAttributeNS("http://www.w3.org/1999/xlink",
"xlink:href",a.src);f.setAttributeNS(null,"width",a.width+"px");f.setAttributeNS(null,"height",a.height+"px");f.setAttributeNS(null,"x","0");f.setAttributeNS(null,"y",g(-c));f.setAttributeNS(null,"transform","scale("+g(1/b)+" "+g(-1/c)+")");this.tgrp.appendChild(f);e.pendingClip?(this.cgrp.appendChild(this.tgrp),this.pgrp.appendChild(this.cgrp)):this.pgrp.appendChild(this.tgrp)},paintImageXObject:function(a){(a=this.objs.get(a))?this.paintInlineImageXObject(a):o("Dependent image isn't ready yet")},
paintInlineImageXObject:function(a,b){var c=this.current,d=a.width,f=a.height,j=e(a),i=document.createElementNS("http://www.w3.org/2000/svg","svg:rect");i.setAttributeNS(null,"x","0");i.setAttributeNS(null,"y","0");i.setAttributeNS(null,"width",g(d));i.setAttributeNS(null,"height",g(f));c.element=i;this.clip("nonzero");i=document.createElementNS("http://www.w3.org/2000/svg","svg:image");i.setAttributeNS("http://www.w3.org/1999/xlink","xlink:href",j);i.setAttributeNS(null,"x","0");i.setAttributeNS(null,
"y",g(-f));i.setAttributeNS(null,"width",g(d)+"px");i.setAttributeNS(null,"height",g(f)+"px");i.setAttributeNS(null,"transform","scale("+g(1/d)+" "+g(-1/f)+")");b?b.appendChild(i):this.tgrp.appendChild(i);c.pendingClip?(this.cgrp.appendChild(this.tgrp),this.pgrp.appendChild(this.cgrp)):this.pgrp.appendChild(this.tgrp)},paintImageMaskXObject:function(a){var b=this.current,c=a.width,e=a.height,f=b.fillColor;b.maskId="mask"+x++;var j=document.createElementNS("http://www.w3.org/2000/svg","svg:mask");
j.setAttributeNS(null,"id",b.maskId);var d=document.createElementNS("http://www.w3.org/2000/svg","svg:rect");d.setAttributeNS(null,"x","0");d.setAttributeNS(null,"y","0");d.setAttributeNS(null,"width",g(c));d.setAttributeNS(null,"height",g(e));d.setAttributeNS(null,"fill",f);d.setAttributeNS(null,"mask","url(#"+b.maskId+")");this.defs.appendChild(j);this.tgrp.appendChild(d);this.paintInlineImageXObject(a,j)},paintFormXObjectBegin:function(a,b){this.save();r(a)&&6===a.length&&this.transform(a[0],a[1],
a[2],a[3],a[4],a[5]);if(r(b)&&4===b.length){var c=b[2]-b[0],e=b[3]-b[1],f=document.createElementNS("http://www.w3.org/2000/svg","svg:rect");f.setAttributeNS(null,"x",b[0]);f.setAttributeNS(null,"y",b[1]);f.setAttributeNS(null,"width",g(c));f.setAttributeNS(null,"height",g(e));this.current.element=f;this.clip("nonzero");this.endPath()}},paintFormXObjectEnd:function(){this.restore()}};return k}();PDFJS.SVGGraphics=y;d.SVGGraphics=y});(function(d,g){g(d.pdfjsDisplayTextLayer={},d.pdfjsSharedUtil,d.pdfjsDisplayDOMUtils,
d.pdfjsSharedGlobal)})(this,function(d,g,A,v){var E=g.Util,G=g.createPromiseCapability,p=A.CustomStyle,l=v.PDFJS,g=function(){function d(c,g,o,t){var t=t[o.fontName],i=document.createElement("div");c.push(i);if(e.test(o.str)){var k=E.transform(g.transform,o.transform),c=Math.atan2(k[1],k[0]);t.vertical&&(c+=Math.PI/2);var n=Math.sqrt(k[2]*k[2]+k[3]*k[3]),m=n;t.ascent?m*=t.ascent:t.descent&&(m*=1+t.descent);var q;0===c?(q=k[4],k=k[5]-m):(q=k[4]+m*Math.sin(c),k=k[5]-m*Math.cos(c));i.style.left=q+"px";
i.style.top=k+"px";i.style.fontSize=n+"px";i.style.fontFamily=t.fontFamily;i.textContent=o.str;l.pdfBug&&(i.dataset.fontName=o.fontName);0!==c&&(i.dataset.angle=c*(180/Math.PI));1<o.str.length&&(i.dataset.canvasWidth=t.vertical?o.height*g.scale:o.width*g.scale)}else i.dataset.isWhitespace=!0}function g(c){if(!c._canceled){var e=c._container,d=c._textDivs,c=c._capability,t=d.length;if(!(t>o)){var i=document.createElement("canvas");i.mozOpaque=!0;for(var i=i.getContext("2d",{alpha:!1}),k,n,m=0;m<t;m++){var q=
d[m];if(void 0===q.dataset.isWhitespace){var l=q.style.fontSize,a=q.style.fontFamily;if(l!==k||a!==n)i.font=l+" "+a,k=l,n=a;l=i.measureText(q.textContent).width;0<l&&(e.appendChild(q),l=void 0!==q.dataset.canvasWidth?"scaleX("+q.dataset.canvasWidth/l+")":"",(a=q.dataset.angle)&&(l="rotate("+a+"deg) "+l),l&&p.setProp("transform",q,l))}}}c.resolve()}}function r(c,e,d,g){this._textContent=c;this._container=e;this._viewport=d;this._textDivs=g=g||[];this._canceled=!1;this._capability=G();this._renderTimer=
null}var o=1E5,e=/\S/;r.prototype={get promise(){return this._capability.promise},cancel:function(){this._canceled=!0;null!==this._renderTimer&&(clearTimeout(this._renderTimer),this._renderTimer=null);this._capability.reject("canceled")},_render:function(c){for(var e=this._textContent.items,o=this._textContent.styles,l=this._textDivs,i=this._viewport,k=0,n=e.length;k<n;k++)d(l,i,e[k],o);if(c){var m=this;this._renderTimer=setTimeout(function(){g(m);m._renderTimer=null},c)}else g(this)}};return function(c){var e=
new r(c.textContent,c.container,c.viewport,c.textDivs);e._render(c.timeout);return e}}();l.renderTextLayer=g;d.renderTextLayer=g});(function(d,g){g(d.pdfjsDisplayWebGL={},d.pdfjsSharedUtil)})(this,function(d,g){var A=g.shadow,v=function(){function d(e,c,g){g=e.createShader(g);e.shaderSource(g,c);e.compileShader(g);if(!e.getShaderParameter(g,e.COMPILE_STATUS))throw e=e.getShaderInfoLog(g),Error("Error during shader compilation: "+e);return g}function g(e,c){for(var d=e.createProgram(),o=0,l=c.length;o<
l;++o)e.attachShader(d,c[o]);e.linkProgram(d);if(!e.getProgramParameter(d,e.LINK_STATUS))throw d=e.getProgramInfoLog(d),Error("Error during program linking: "+d);return d}function p(e,c,d){e.activeTexture(d);d=e.createTexture();e.bindTexture(e.TEXTURE_2D,d);e.texParameteri(e.TEXTURE_2D,e.TEXTURE_WRAP_S,e.CLAMP_TO_EDGE);e.texParameteri(e.TEXTURE_2D,e.TEXTURE_WRAP_T,e.CLAMP_TO_EDGE);e.texParameteri(e.TEXTURE_2D,e.TEXTURE_MIN_FILTER,e.NEAREST);e.texParameteri(e.TEXTURE_2D,e.TEXTURE_MAG_FILTER,e.NEAREST);
e.texImage2D(e.TEXTURE_2D,0,e.RGBA,e.RGBA,e.UNSIGNED_BYTE,c);return d}function l(){v||(B=document.createElement("canvas"),v=B.getContext("webgl",{premultipliedalpha:!1}))}var v,B,r=null,o=null;return{get isEnabled(){if(PDFJS.disableWebGL)return!1;var e=!1;try{l(),e=!!v}catch(c){}return A(this,"isEnabled",e)},composeSMask:function(e,c,o){var C=e.width,t=e.height;if(!r){var i,k;l();i=B;B=null;k=v;v=null;var n=d(k,"  attribute vec2 a_position;                                      attribute vec2 a_texCoord;                                                                                                      uniform vec2 u_resolution;                                                                                                      varying vec2 v_texCoord;                                                                                                        void main() {                                                     vec2 clipSpace = (a_position / u_resolution) * 2.0 - 1.0;       gl_Position = vec4(clipSpace * vec2(1, -1), 0, 1);                                                                              v_texCoord = a_texCoord;                                      }                                                             ",
k.VERTEX_SHADER),m=d(k,"  precision mediump float;                                                                                                        uniform vec4 u_backdrop;                                        uniform int u_subtype;                                          uniform sampler2D u_image;                                      uniform sampler2D u_mask;                                                                                                       varying vec2 v_texCoord;                                                                                                        void main() {                                                     vec4 imageColor = texture2D(u_image, v_texCoord);               vec4 maskColor = texture2D(u_mask, v_texCoord);                 if (u_backdrop.a > 0.0) {                                         maskColor.rgb = maskColor.rgb * maskColor.a +                                   u_backdrop.rgb * (1.0 - maskColor.a);         }                                                               float lum;                                                      if (u_subtype == 0) {                                             lum = maskColor.a;                                            } else {                                                          lum = maskColor.r * 0.3 + maskColor.g * 0.59 +                        maskColor.b * 0.11;                                     }                                                               imageColor.a *= lum;                                            imageColor.rgb *= imageColor.a;                                 gl_FragColor = imageColor;                                    }                                                             ",
k.FRAGMENT_SHADER),q=g(k,[n,m]);k.useProgram(q);n={};n.gl=k;n.canvas=i;n.resolutionLocation=k.getUniformLocation(q,"u_resolution");n.positionLocation=k.getAttribLocation(q,"a_position");n.backdropLocation=k.getUniformLocation(q,"u_backdrop");n.subtypeLocation=k.getUniformLocation(q,"u_subtype");i=k.getAttribLocation(q,"a_texCoord");var m=k.getUniformLocation(q,"u_image"),q=k.getUniformLocation(q,"u_mask"),x=k.createBuffer();k.bindBuffer(k.ARRAY_BUFFER,x);k.bufferData(k.ARRAY_BUFFER,new Float32Array([0,
0,1,0,0,1,0,1,1,0,1,1]),k.STATIC_DRAW);k.enableVertexAttribArray(i);k.vertexAttribPointer(i,2,k.FLOAT,!1,0,0);k.uniform1i(m,0);k.uniform1i(q,1);r=n}k=r;n=k.canvas;i=k.gl;n.width=C;n.height=t;i.viewport(0,0,i.drawingBufferWidth,i.drawingBufferHeight);i.uniform2f(k.resolutionLocation,C,t);o.backdrop?i.uniform4f(k.resolutionLocation,o.backdrop[0],o.backdrop[1],o.backdrop[2],1):i.uniform4f(k.resolutionLocation,0,0,0,0);i.uniform1i(k.subtypeLocation,"Luminosity"===o.subtype?1:0);e=p(i,e,i.TEXTURE0);c=
p(i,c,i.TEXTURE1);o=i.createBuffer();i.bindBuffer(i.ARRAY_BUFFER,o);i.bufferData(i.ARRAY_BUFFER,new Float32Array([0,0,C,0,0,t,0,t,C,0,C,t]),i.STATIC_DRAW);i.enableVertexAttribArray(k.positionLocation);i.vertexAttribPointer(k.positionLocation,2,i.FLOAT,!1,0,0);i.clearColor(0,0,0,0);i.enable(i.BLEND);i.blendFunc(i.ONE,i.ONE_MINUS_SRC_ALPHA);i.clear(i.COLOR_BUFFER_BIT);i.drawArrays(i.TRIANGLES,0,6);i.flush();i.deleteTexture(e);i.deleteTexture(c);i.deleteBuffer(o);return n},drawFigures:function(e,c,y,
r,t){if(!o){var i,k;l();i=B;B=null;k=v;v=null;var n=d(k,"  attribute vec2 a_position;                                      attribute vec3 a_color;                                                                                                         uniform vec2 u_resolution;                                      uniform vec2 u_scale;                                           uniform vec2 u_offset;                                                                                                          varying vec4 v_color;                                                                                                           void main() {                                                     vec2 position = (a_position + u_offset) * u_scale;              vec2 clipSpace = (position / u_resolution) * 2.0 - 1.0;         gl_Position = vec4(clipSpace * vec2(1, -1), 0, 1);                                                                              v_color = vec4(a_color / 255.0, 1.0);                         }                                                             ",
k.VERTEX_SHADER),m=d(k,"  precision mediump float;                                                                                                        varying vec4 v_color;                                                                                                           void main() {                                                     gl_FragColor = v_color;                                       }                                                             ",k.FRAGMENT_SHADER),n=g(k,[n,
m]);k.useProgram(n);m={};m.gl=k;m.canvas=i;m.resolutionLocation=k.getUniformLocation(n,"u_resolution");m.scaleLocation=k.getUniformLocation(n,"u_scale");m.offsetLocation=k.getUniformLocation(n,"u_offset");m.positionLocation=k.getAttribLocation(n,"a_position");m.colorLocation=k.getAttribLocation(n,"a_color");o=m}i=o;k=i.canvas;n=i.gl;k.width=e;k.height=c;n.viewport(0,0,n.drawingBufferWidth,n.drawingBufferHeight);n.uniform2f(i.resolutionLocation,e,c);var e=0,q,x,a;for(q=0,x=r.length;q<x;q++)switch(r[q].type){case "lattice":a=
r[q].coords.length/r[q].verticesPerRow|0;e+=6*(a-1)*(r[q].verticesPerRow-1);break;case "triangles":e+=r[q].coords.length}var m=new Float32Array(2*e),c=new Uint8Array(3*e),b=t.coords,h=t.colors,w=0,f=0;for(q=0,x=r.length;q<x;q++){a=r[q];var j=a.coords,u=a.colors;switch(a.type){case "lattice":var H=a.verticesPerRow;a=j.length/H|0;for(var M=1;M<a;M++)for(var p=M*H+1,z=1;z<H;z++,p++)m[w]=b[j[p-H-1]],m[w+1]=b[j[p-H-1]+1],m[w+2]=b[j[p-H]],m[w+3]=b[j[p-H]+1],m[w+4]=b[j[p-1]],m[w+5]=b[j[p-1]+1],c[f]=h[u[p-
H-1]],c[f+1]=h[u[p-H-1]+1],c[f+2]=h[u[p-H-1]+2],c[f+3]=h[u[p-H]],c[f+4]=h[u[p-H]+1],c[f+5]=h[u[p-H]+2],c[f+6]=h[u[p-1]],c[f+7]=h[u[p-1]+1],c[f+8]=h[u[p-1]+2],m[w+6]=m[w+2],m[w+7]=m[w+3],m[w+8]=m[w+4],m[w+9]=m[w+5],m[w+10]=b[j[p]],m[w+11]=b[j[p]+1],c[f+9]=c[f+3],c[f+10]=c[f+4],c[f+11]=c[f+5],c[f+12]=c[f+6],c[f+13]=c[f+7],c[f+14]=c[f+8],c[f+15]=h[u[p]],c[f+16]=h[u[p]+1],c[f+17]=h[u[p]+2],w+=12,f+=18;break;case "triangles":a=0;for(H=j.length;a<H;a++)m[w]=b[j[a]],m[w+1]=b[j[a]+1],c[f]=h[u[a]],c[f+1]=
h[u[a]+1],c[f+2]=h[u[a]+2],w+=2,f+=3}}y?n.clearColor(y[0]/255,y[1]/255,y[2]/255,1):n.clearColor(0,0,0,0);n.clear(n.COLOR_BUFFER_BIT);y=n.createBuffer();n.bindBuffer(n.ARRAY_BUFFER,y);n.bufferData(n.ARRAY_BUFFER,m,n.STATIC_DRAW);n.enableVertexAttribArray(i.positionLocation);n.vertexAttribPointer(i.positionLocation,2,n.FLOAT,!1,0,0);r=n.createBuffer();n.bindBuffer(n.ARRAY_BUFFER,r);n.bufferData(n.ARRAY_BUFFER,c,n.STATIC_DRAW);n.enableVertexAttribArray(i.colorLocation);n.vertexAttribPointer(i.colorLocation,
3,n.UNSIGNED_BYTE,!1,0,0);n.uniform2f(i.scaleLocation,t.scaleX,t.scaleY);n.uniform2f(i.offsetLocation,t.offsetX,t.offsetY);n.drawArrays(n.TRIANGLES,0,e);n.flush();n.deleteBuffer(y);n.deleteBuffer(r);return k},clear:function(){r&&r.canvas&&(r.canvas.width=0,r.canvas.height=0);o&&o.canvas&&(o.canvas.width=0,o.canvas.height=0);o=r=null}}}();d.WebGLUtils=v});(function(d,g){g(d.pdfjsDisplayPatternHelper={},d.pdfjsSharedUtil,d.pdfjsDisplayWebGL)})(this,function(d,g,A){var v=g.Util,E=g.info,G=g.isArray,
p=g.error,l=A.WebGLUtils,I={RadialAxial:{fromIR:function(d){var g=d[1],e=d[2],c=d[3],l=d[4],p=d[5],t=d[6];return{type:"Pattern",getPattern:function(d){var k;"axial"===g?k=d.createLinearGradient(c[0],c[1],l[0],l[1]):"radial"===g&&(k=d.createRadialGradient(c[0],c[1],p,l[0],l[1],t));for(var d=0,n=e.length;d<n;++d){var m=e[d];k.addColorStop(m[0],m[1])}return k}}}}},B=function(){function d(g,e,c,l,p,t,i,k){var n=e.coords,m=e.colors,q=g.data,g=4*g.width,r;n[c+1]>n[l+1]&&(r=c,c=l,l=r,r=t,t=i,i=r);n[l+1]>
n[p+1]&&(r=l,l=p,p=r,r=i,i=k,k=r);n[c+1]>n[l+1]&&(r=c,c=l,l=r,r=t,t=i,i=r);r=(n[c]+e.offsetX)*e.scaleX;var c=(n[c+1]+e.offsetY)*e.scaleY,a=(n[l]+e.offsetX)*e.scaleX,l=(n[l+1]+e.offsetY)*e.scaleY,b=(n[p]+e.offsetX)*e.scaleX,e=(n[p+1]+e.offsetY)*e.scaleY;if(!(c>=e))for(var p=m[t],n=m[t+1],t=m[t+2],h=m[i],w=m[i+1],i=m[i+2],f=m[k],j=m[k+1],k=m[k+2],u=Math.round(c),m=Math.round(e),H,M,v,z,A,O,B,D,s=u;s<=m;s++){s<l?(D=s<c?0:c===l?1:(c-s)/(c-l),u=r-(r-a)*D,H=p-(p-h)*D,M=n-(n-w)*D,v=t-(t-i)*D):(D=s>e?1:l===
e?0:(l-s)/(l-e),u=a-(a-b)*D,H=h-(h-f)*D,M=w-(w-j)*D,v=i-(i-k)*D);D=s<c?0:s>e?1:(c-s)/(c-e);z=r-(r-b)*D;A=p-(p-f)*D;O=n-(n-j)*D;B=t-(t-k)*D;D=Math.round(Math.min(u,z));for(var F=Math.round(Math.max(u,z)),L=g*s+4*D,K=D;K<=F;K++)D=(u-K)/(u-z),D=0>D?0:1<D?1:D,q[L++]=H-(H-A)*D|0,q[L++]=M-(M-O)*D|0,q[L++]=v-(v-B)*D|0,q[L++]=255}}return function(g,e,c,v,C,t,i){var k=Math.floor(g[0]),n=Math.floor(g[1]),m=Math.ceil(g[2])-k,g=Math.ceil(g[3])-n,q=Math.min(Math.ceil(Math.abs(1.1*m*e[0])),3E3),e=Math.min(Math.ceil(Math.abs(1.1*
g*e[1])),3E3),m=m/q,g=g/e,c={coords:c,colors:v,offsetX:-k,offsetY:-n,scaleX:1/m,scaleY:1/g},x;if(l.isEnabled)C=l.drawFigures(q,e,t,C,c),i=i.getCanvas("mesh",q,e,!1),i.context.drawImage(C,0,0);else{i=i.getCanvas("mesh",q,e,!1);v=i.context;e=v.createImageData(q,e);if(t){var a=e.data;for(q=0,x=a.length;q<x;q+=4)a[q]=t[0],a[q+1]=t[1],a[q+2]=t[2],a[q+3]=255}for(q=0;q<C.length;q++){var t=e,b=C[q];x=c;var a=b.coords,h=b.colors,w=void 0,f=void 0;switch(b.type){case "lattice":for(var b=b.verticesPerRow,f=
Math.floor(a.length/b)-1,j=b-1,w=0;w<f;w++)for(var u=w*b,H=0;H<j;H++,u++)d(t,x,a[u],a[u+1],a[u+b],h[u],h[u+1],h[u+b]),d(t,x,a[u+b+1],a[u+1],a[u+b],h[u+b+1],h[u+1],h[u+b]);break;case "triangles":for(w=0,f=a.length;w<f;w+=3)d(t,x,a[w],a[w+1],a[w+2],h[w],h[w+1],h[w+2]);break;default:p("illigal figure")}}v.putImageData(e,0,0)}C=i.canvas;return{canvas:C,offsetX:k,offsetY:n,scaleX:m,scaleY:g}}}();I.Mesh={fromIR:function(d){var g=d[2],e=d[3],c=d[4],l=d[5],p=d[6],t=d[8];return{type:"Pattern",getPattern:function(d,
k,n){var m;if(n)m=v.singularValueDecompose2dScale(d.mozCurrentTransform);else if(m=v.singularValueDecompose2dScale(k.baseTransform),p){var r=v.singularValueDecompose2dScale(p);m=[m[0]*r[0],m[1]*r[1]]}m=B(l,m,g,e,c,n?null:t,k.cachedCanvases);n||(d.setTransform.apply(d,k.baseTransform),p&&d.transform.apply(d,p));d.translate(m.offsetX,m.offsetY);d.scale(m.scaleX,m.scaleY);return d.createPattern(m.canvas,"no-repeat")}}}};I.Dummy={fromIR:function(){return{type:"Pattern",getPattern:function(){return"hotpink"}}}};
g=function(){function d(g,e,c,l,p){this.operatorList=g[2];this.matrix=g[3]||[1,0,0,1,0,0];this.bbox=g[4];this.xstep=g[5];this.ystep=g[6];this.paintType=g[7];this.tilingType=g[8];this.color=e;this.canvasGraphicsFactory=l;this.baseTransform=p;this.type="Pattern";this.ctx=c}d.prototype={createPatternCanvas:function(d){var e=this.operatorList,c=this.bbox,g=this.xstep,l=this.ystep,p=this.paintType,i=this.color,k=this.canvasGraphicsFactory;E("TilingType: "+this.tilingType);var n=c[0],m=c[1],r=c[2],x=c[3],
a=[n,m],b=[n+g,m+l],h=b[0]-a[0],b=b[1]-a[1],w=v.singularValueDecompose2dScale(this.matrix),f=v.singularValueDecompose2dScale(this.baseTransform),w=[w[0]*f[0],w[1]*f[1]],h=Math.min(Math.ceil(Math.abs(h*w[0])),3E3),b=Math.min(Math.ceil(Math.abs(b*w[1])),3E3),w=d.cachedCanvases.getCanvas("pattern",h,b,!0),f=w.context,k=k.createCanvasGraphics(f);k.groupLevel=d.groupLevel;this.setFillAndStrokeStyleToContext(f,p,i);this.setScale(h,b,g,l);this.transformToScale(k);k.transform.apply(k,[1,0,0,1,-a[0],-a[1]]);
this.clipBbox(k,c,n,m,r,x);k.executeOperatorList(e);return w.canvas},setScale:function(d,e,c,g){this.scale=[d/c,e/g]},transformToScale:function(d){var e=this.scale;d.transform.apply(d,[e[0],0,0,e[1],0,0])},scaleToContext:function(){var d=this.scale;this.ctx.scale(1/d[0],1/d[1])},clipBbox:function(d,e,c,g,l,p){e&&G(e)&&4===e.length&&(d.ctx.rect(c,g,l-c,p-g),d.clip(),d.endPath())},setFillAndStrokeStyleToContext:function(d,e,c){switch(e){case 1:e=this.ctx;d.fillStyle=e.fillStyle;d.strokeStyle=e.strokeStyle;
break;case 2:e=v.makeCssRgb(c[0],c[1],c[2]);d.fillStyle=e;d.strokeStyle=e;break;default:p("Unsupported paint type: "+e)}},getPattern:function(d,e){var c=this.createPatternCanvas(e),d=this.ctx;d.setTransform.apply(d,this.baseTransform);d.transform.apply(d,this.matrix);this.scaleToContext();return d.createPattern(c,"repeat")}};return d}();d.getShadingPatternFromIR=function(d){var g=I[d[0]];g||p("Unknown IR type: "+d[0]);return g.fromIR(d)};d.TilingPattern=g});(function(d,g){g(d.pdfjsDisplayCanvas={},
d.pdfjsSharedUtil,d.pdfjsDisplayPatternHelper,d.pdfjsDisplayWebGL)})(this,function(d,g,A,v){function E(a,b){var c=document.createElement("canvas");c.width=a;c.height=b;return c}function G(a){a.mozCurrentTransform||(a._originalSave=a.save,a._originalRestore=a.restore,a._originalRotate=a.rotate,a._originalScale=a.scale,a._originalTranslate=a.translate,a._originalTransform=a.transform,a._originalSetTransform=a.setTransform,a._transformMatrix=a._transformMatrix||[1,0,0,1,0,0],a._transformStack=[],Object.defineProperty(a,
"mozCurrentTransform",{get:function(){return this._transformMatrix}}),Object.defineProperty(a,"mozCurrentTransformInverse",{get:function(){var a=this._transformMatrix,b=a[0],c=a[1],f=a[2],d=a[3],e=a[4],a=a[5],g=b*d-c*f,h=c*f-b*d;return[d/g,c/h,f/h,b/g,(d*e-f*a)/h,(c*e-b*a)/g]}}),a.save=function(){var a=this._transformMatrix;this._transformStack.push(a);this._transformMatrix=a.slice(0,6);this._originalSave()},a.restore=function(){var a=this._transformStack.pop();a&&(this._transformMatrix=a,this._originalRestore())},
a.translate=function(a,b){var c=this._transformMatrix;c[4]=c[0]*a+c[2]*b+c[4];c[5]=c[1]*a+c[3]*b+c[5];this._originalTranslate(a,b)},a.scale=function(a,b){var c=this._transformMatrix;c[0]*=a;c[1]*=a;c[2]*=b;c[3]*=b;this._originalScale(a,b)},a.transform=function(b,c,d,e,g,h){var i=this._transformMatrix;this._transformMatrix=[i[0]*b+i[2]*c,i[1]*b+i[3]*c,i[0]*d+i[2]*e,i[1]*d+i[3]*e,i[0]*g+i[2]*h+i[4],i[1]*g+i[3]*h+i[5]];a._originalTransform(b,c,d,e,g,h)},a.setTransform=function(b,c,d,e,g,h){this._transformMatrix=
[b,c,d,e,g,h];a._originalSetTransform(b,c,d,e,g,h)},a.rotate=function(a){var b=Math.cos(a),c=Math.sin(a),d=this._transformMatrix;this._transformMatrix=[d[0]*b+d[2]*c,d[1]*b+d[3]*c,d[0]*-c+d[2]*b,d[1]*-c+d[3]*b,d[4],d[5]];this._originalRotate(a)})}function p(a){var b=a.width,c=a.height,d,e,g=b+1,h=new Uint8Array(g*(c+1)),i=new Uint8Array([0,2,4,0,1,0,5,4,8,10,0,8,0,2,1,0]),k=b+7&-8,m=a.data,l=new Uint8Array(k*c),s=0;for(a=0,d=m.length;a<d;a++){e=128;for(var F=m[a];0<e;)l[s++]=F&e?0:255,e>>=1}s=m=0;
0!==l[s]&&(h[0]=1,++m);for(d=1;d<b;d++)l[s]!==l[s+1]&&(h[d]=l[s]?2:1,++m),s++;0!==l[s]&&(h[d]=2,++m);for(a=1;a<c;a++){s=a*k;e=a*g;l[s-k]!==l[s]&&(h[e]=l[s]?1:8,++m);F=(l[s]?4:0)+(l[s-k]?8:0);for(d=1;d<b;d++)F=(F>>2)+(l[s+1]?4:0)+(l[s-k+1]?8:0),i[F]&&(h[e+d]=i[F],++m),s++;l[s-k]!==l[s]&&(h[e+d]=l[s]?2:4,++m);if(1E3<m)return null}s=k*(c-1);e=a*g;0!==l[s]&&(h[e]=8,++m);for(d=1;d<b;d++)l[s]!==l[s+1]&&(h[e+d]=l[s]?4:8,++m),s++;0!==l[s]&&(h[e+d]=4,++m);if(1E3<m)return null;for(var i=new Int32Array([0,g,
-1,0,-g,0,0,0,1]),L=[],a=0;m&&a<=c;a++){k=a*g;for(l=k+b;k<l&&!h[k];)k++;if(k!==l){l=[k%g,a];s=h[k];d=k;do{e=i[s];do k+=e;while(!h[k]);e=h[k];5!==e&&10!==e?(s=e,h[k]=0):(s=e&51*s>>4,h[k]&=s>>2|s<<2);l.push(k%g);l.push(k/g|0);--m}while(d!==k);L.push(l);--a}}return function(a){a.save();a.scale(1/b,-1/c);a.translate(0,-c);a.beginPath();for(var d=0,s=L.length;d<s;d++){var e=L[d];a.moveTo(e[0],e[1]);for(var f=2,g=e.length;f<g;f+=2)a.lineTo(e[f],e[f+1])}a.fill();a.beginPath();a.restore()}}var l=g.FONT_IDENTITY_MATRIX,
I=g.IDENTITY_MATRIX,B=g.ImageKind,r=g.OPS,o=g.TextRenderingMode,e=g.Uint32ArrayView,c=g.Util,y=g.assert,C=g.info,t=g.isNum,i=g.isArray,k=g.error,n=g.shadow,m=g.warn,q=A.TilingPattern,x=A.getShadingPatternFromIR,a=v.WebGLUtils,b=16,h=function(){function a(){this.cache=Object.create(null)}a.prototype={getCanvas:function(a,b,c,d){void 0!==this.cache[a]?(a=this.cache[a],a.canvas.width=b,a.canvas.height=c,a.context.setTransform(1,0,0,1,0,0)):(b=E(b,c),c=b.getContext("2d"),d&&G(c),this.cache[a]=a={canvas:b,
context:c});return a},clear:function(){for(var a in this.cache){var b=this.cache[a];b.canvas.width=0;b.canvas.height=0;delete this.cache[a]}}};return a}(),w=function(){function a(b){this.alphaIsShape=!1;this.fontSize=0;this.fontSizeScale=1;this.textMatrix=I;this.textMatrixScale=1;this.fontMatrix=l;this.wordSpacing=this.charSpacing=this.lineY=this.lineX=this.y=this.x=this.leading=0;this.textHScale=1;this.textRenderingMode=o.FILL;this.textRise=0;this.strokeColor=this.fillColor="#000000";this.patternFill=
!1;this.lineWidth=this.strokeAlpha=this.fillAlpha=1;this.activeSMask=null;this.old=b}a.prototype={clone:function(){return Object.create(this)},setCurrentPoint:function(a,b){this.x=a;this.y=b}};return a}(),g=function(){function d(a,b,c,e){this.ctx=a;this.current=new w;this.stateStack=[];this.pendingClip=null;this.pendingEOFill=!1;this.xobjs=this.res=null;this.commonObjs=b;this.objs=c;this.imageLayer=e;this.groupStack=[];this.baseTransform=this.processingType3=null;this.baseTransformStack=[];this.groupLevel=
0;this.smaskStack=[];this.smaskCounter=0;this.tempSMask=null;this.cachedCanvases=new h;a&&G(a);this.cachedGetSinglePixelWidth=null}function g(a,c){if("undefined"!==typeof ImageData&&c instanceof ImageData)a.putImageData(c,0,0);else{var d=c.height,f=c.width,J=d%b,d=(d-J)/b,h=0===J?d:d+1,N=a.createImageData(f,b),i=0,j,m=c.data,l=N.data,n,p,o;if(c.kind===B.GRAYSCALE_1BPP){var r=m.byteLength,l=PDFJS.hasCanvasTypedArrays?new Uint32Array(l.buffer):new e(l),t=l.length,q=f+7>>3,v=PDFJS.isLittleEndian||!PDFJS.hasCanvasTypedArrays?
4278190080:255;for(n=0;n<h;n++){o=n<d?b:J;for(p=j=0;p<o;p++){for(var u=r-i,w=0,u=u>q?f:8*u-7,z=u&-8,x=0,A=0;w<z;w+=8)A=m[i++],l[j++]=A&128?4294967295:v,l[j++]=A&64?4294967295:v,l[j++]=A&32?4294967295:v,l[j++]=A&16?4294967295:v,l[j++]=A&8?4294967295:v,l[j++]=A&4?4294967295:v,l[j++]=A&2?4294967295:v,l[j++]=A&1?4294967295:v;for(;w<u;w++)0===x&&(A=m[i++],x=128),l[j++]=A&x?4294967295:v,x>>=1}for(;j<t;)l[j++]=0;a.putImageData(N,0,n*b)}}else if(c.kind===B.RGBA_32BPP){p=0;o=4*f*b;for(n=0;n<d;n++)l.set(m.subarray(i,
i+o)),i+=o,a.putImageData(N,0,p),p+=b;n<h&&(l.set(m.subarray(i,i+4*f*J)),a.putImageData(N,0,p))}else if(c.kind===B.RGB_24BPP){o=b;o*=f;for(n=0;n<h;n++){n>=d&&(o=J,o*=f);j=0;for(p=o;p--;)l[j++]=m[i++],l[j++]=m[i++],l[j++]=m[i++],l[j++]=255;a.putImageData(N,0,n*b)}}else k("bad image kind: "+c.kind)}}function u(a,c){for(var d=c.height,e=c.width,f=d%b,d=(d-f)/b,g=0===f?d:d+1,h=a.createImageData(e,b),i=0,j=c.data,k=h.data,l=0;l<g;l++){for(var m=l<d?b:f,n=3,p=0;p<m;p++)for(var o=0,r=0;r<e;r++){if(!o)var t=
j[i++],o=128;k[n]=t&o?0:255;n+=4;o>>=1}a.putImageData(h,0,l*b)}}function v(a,b){for(var c="strokeStyle,fillStyle,fillRule,globalAlpha,lineWidth,lineCap,lineJoin,miterLimit,globalCompositeOperation,font".split(","),d=0,e=c.length;d<e;d++){var f=c[d];void 0!==a[f]&&(b[f]=a[f])}void 0!==a.setLineDash?(b.setLineDash(a.getLineDash()),b.lineDashOffset=a.lineDashOffset):void 0!==a.mozDashOffset&&(b.mozDash=a.mozDash,b.mozDashOffset=a.mozDashOffset)}function A(a,b,c){for(var d=a.length,e=1/255,f=3;f<d;f+=
4)b[f]=b[f]*(c?c[a[f]]:a[f])*e|0}function E(a,b,c){for(var d=a.length,e=3;e<d;e+=4){var f=77*a[e-3]+152*a[e-2]+28*a[e-1];b[e]=c?b[e]*c[f>>8]>>8:b[e]*f>>16}}var z=["butt","round","square"],Q=["miter","round","bevel"],O={},R={};d.prototype={beginDrawing:function(a,b,c){var d=this.ctx.canvas.width,e=this.ctx.canvas.height;this.ctx.save();this.ctx.fillStyle="rgb(255, 255, 255)";this.ctx.fillRect(0,0,d,e);this.ctx.restore();c&&(c=this.cachedCanvases.getCanvas("transparent",d,e,!0),this.compositeCtx=this.ctx,
this.transparentCanvas=c.canvas,this.ctx=c.context,this.ctx.save(),this.ctx.transform.apply(this.ctx,this.compositeCtx.mozCurrentTransform));this.ctx.save();a&&this.ctx.transform.apply(this.ctx,a);this.ctx.transform.apply(this.ctx,b.transform);this.baseTransform=this.ctx.mozCurrentTransform.slice();this.imageLayer&&this.imageLayer.beginLayout()},executeOperatorList:function(a,b,c,d){var e=a.argsArray,a=a.fnArray,b=b||0,f=e.length;if(f===b)return b;for(var g=10<f-b&&"function"===typeof c,h=g?Date.now()+
15:0,i=0,j=this.commonObjs,k=this.objs,l;;){if(void 0!==d&&b===d.nextBreakPoint)return d.breakIt(b,c),b;l=a[b];if(l!==r.dependency)this[l].apply(this,e[b]);else{l=e[b];for(var m=0,n=l.length;m<n;m++){var o=l[m],p="g"===o[0]&&"_"===o[1]?j:k;if(!p.isResolved(o))return p.get(o,c),b}}b++;if(b===f)return b;if(g&&10<++i){if(Date.now()>h)return c(),b;i=0}}},endDrawing:function(){this.ctx.restore();this.transparentCanvas&&(this.ctx=this.compositeCtx,this.ctx.drawImage(this.transparentCanvas,0,0),this.transparentCanvas=
null);this.cachedCanvases.clear();a.clear();this.imageLayer&&this.imageLayer.endLayout()},setLineWidth:function(a){this.current.lineWidth=a;this.ctx.lineWidth=a},setLineCap:function(a){this.ctx.lineCap=z[a]},setLineJoin:function(a){this.ctx.lineJoin=Q[a]},setMiterLimit:function(a){this.ctx.miterLimit=a},setDash:function(a,b){var c=this.ctx;void 0!==c.setLineDash?(c.setLineDash(a),c.lineDashOffset=b):(c.mozDash=a,c.mozDashOffset=b)},setRenderingIntent:function(){},setFlatness:function(){},setGState:function(a){for(var b=
0,c=a.length;b<c;b++){var d=a[b],e=d[1];switch(d[0]){case "LW":this.setLineWidth(e);break;case "LC":this.setLineCap(e);break;case "LJ":this.setLineJoin(e);break;case "ML":this.setMiterLimit(e);break;case "D":this.setDash(e[0],e[1]);break;case "RI":this.setRenderingIntent(e);break;case "FL":this.setFlatness(e);break;case "Font":this.setFont(e[0],e[1]);break;case "CA":this.current.strokeAlpha=d[1];break;case "ca":this.current.fillAlpha=d[1];this.ctx.globalAlpha=d[1];break;case "BM":e&&e.name&&"Normal"!==
e.name?(d=e.name.replace(/([A-Z])/g,function(a){return"-"+a.toLowerCase()}).substring(1),this.ctx.globalCompositeOperation=d,this.ctx.globalCompositeOperation!==d&&m('globalCompositeOperation "'+d+'" is not supported')):this.ctx.globalCompositeOperation="source-over";break;case "SMask":this.current.activeSMask&&this.endSMaskGroup(),this.current.activeSMask=e?this.tempSMask:null,this.current.activeSMask&&this.beginSMaskGroup(),this.tempSMask=null}}},beginSMaskGroup:function(){var a=this.current.activeSMask,
b=this.cachedCanvases.getCanvas("smaskGroupAt"+this.groupLevel,a.canvas.width,a.canvas.height,!0),c=this.ctx,d=c.mozCurrentTransform;this.ctx.save();b=b.context;b.scale(1/a.scaleX,1/a.scaleY);b.translate(-a.offsetX,-a.offsetY);b.transform.apply(b,d);v(c,b);this.ctx=b;this.setGState([["BM","Normal"],["ca",1],["CA",1]]);this.groupStack.push(c);this.groupLevel++},endSMaskGroup:function(){var b=this.ctx;this.groupLevel--;this.ctx=this.groupStack.pop();var c=this.ctx,d=this.current.activeSMask,e=d.canvas,
f=d.context;c.setTransform(d.scaleX,0,0,d.scaleY,d.offsetX,d.offsetY);var g=d.backdrop||null;if(!d.transferMap&&a.isEnabled)e=a.composeSMask(b.canvas,e,{subtype:d.subtype,backdrop:g}),c.setTransform(1,0,0,1,0,0),c.drawImage(e,d.offsetX,d.offsetY);else{for(var h=e.width,i=e.height,j=d.transferMap,k=!!g,l=k?g[0]:0,m=k?g[1]:0,g=k?g[2]:0,d="Luminosity"===d.subtype?E:A,n=Math.min(i,Math.ceil(1048576/h)),o=0;o<i;o+=n){var p=Math.min(n,i-o),r=f.getImageData(0,o,h,p),p=b.getImageData(0,o,h,p);if(k)for(var t=
r.data,q=l,u=m,w=g,z=t.length,x=3;x<z;x+=4){var y=t[x];if(0===y)t[x-3]=q,t[x-2]=u,t[x-1]=w;else if(255>y){var B=255-y;t[x-3]=t[x-3]*y+q*B>>8;t[x-2]=t[x-2]*y+u*B>>8;t[x-1]=t[x-1]*y+w*B>>8}}d(r.data,p.data,j);f.putImageData(p,0,o)}c.drawImage(e,0,0)}this.ctx.restore();v(b,this.ctx)},save:function(){this.ctx.save();var a=this.current;this.stateStack.push(a);this.current=a.clone();this.current.activeSMask=null},restore:function(){0!==this.stateStack.length&&(null!==this.current.activeSMask&&this.endSMaskGroup(),
this.current=this.stateStack.pop(),this.ctx.restore(),this.cachedGetSinglePixelWidth=this.pendingClip=null)},transform:function(a,b,c,d,e,f){this.ctx.transform(a,b,c,d,e,f);this.cachedGetSinglePixelWidth=null},constructPath:function(a,b){for(var c=this.ctx,d=this.current,e=d.x,f=d.y,g=0,h=0,i=a.length;g<i;g++)switch(a[g]|0){case r.rectangle:var e=b[h++],f=b[h++],j=b[h++],k=b[h++];0===j&&(j=this.getSinglePixelWidth());0===k&&(k=this.getSinglePixelWidth());j=e+j;k=f+k;this.ctx.moveTo(e,f);this.ctx.lineTo(j,
f);this.ctx.lineTo(j,k);this.ctx.lineTo(e,k);this.ctx.lineTo(e,f);this.ctx.closePath();break;case r.moveTo:e=b[h++];f=b[h++];c.moveTo(e,f);break;case r.lineTo:e=b[h++];f=b[h++];c.lineTo(e,f);break;case r.curveTo:e=b[h+4];f=b[h+5];c.bezierCurveTo(b[h],b[h+1],b[h+2],b[h+3],e,f);h+=6;break;case r.curveTo2:c.bezierCurveTo(e,f,b[h],b[h+1],b[h+2],b[h+3]);e=b[h+2];f=b[h+3];h+=4;break;case r.curveTo3:e=b[h+2];f=b[h+3];c.bezierCurveTo(b[h],b[h+1],e,f,e,f);h+=4;break;case r.closePath:c.closePath()}d.setCurrentPoint(e,
f)},closePath:function(){this.ctx.closePath()},stroke:function(a){var a="undefined"!==typeof a?a:!0,b=this.ctx,c=this.current.strokeColor;b.lineWidth=Math.max(0.65*this.getSinglePixelWidth(),this.current.lineWidth);b.globalAlpha=this.current.strokeAlpha;c&&c.hasOwnProperty("type")&&"Pattern"===c.type?(b.save(),b.strokeStyle=c.getPattern(b,this),b.stroke(),b.restore()):b.stroke();a&&this.consumePath();b.globalAlpha=this.current.fillAlpha},closeStroke:function(){this.closePath();this.stroke()},fill:function(a){var a=
"undefined"!==typeof a?a:!0,b=this.ctx,c=this.current.fillColor,d=!1;this.current.patternFill&&(b.save(),this.baseTransform&&b.setTransform.apply(b,this.baseTransform),b.fillStyle=c.getPattern(b,this),d=!0);this.pendingEOFill?(void 0!==b.mozFillRule?(b.mozFillRule="evenodd",b.fill(),b.mozFillRule="nonzero"):b.fill("evenodd"),this.pendingEOFill=!1):b.fill();d&&b.restore();a&&this.consumePath()},eoFill:function(){this.pendingEOFill=!0;this.fill()},fillStroke:function(){this.fill(!1);this.stroke(!1);
this.consumePath()},eoFillStroke:function(){this.pendingEOFill=!0;this.fillStroke()},closeFillStroke:function(){this.closePath();this.fillStroke()},closeEOFillStroke:function(){this.pendingEOFill=!0;this.closePath();this.fillStroke()},endPath:function(){this.consumePath()},clip:function(){this.pendingClip=O},eoClip:function(){this.pendingClip=R},beginText:function(){this.current.textMatrix=I;this.current.textMatrixScale=1;this.current.x=this.current.lineX=0;this.current.y=this.current.lineY=0},endText:function(){var a=
this.pendingTextPaths,b=this.ctx;if(void 0===a)b.beginPath();else{b.save();b.beginPath();for(var c=0;c<a.length;c++){var d=a[c];b.setTransform.apply(b,d.transform);b.translate(d.x,d.y);d.addToPath(b,d.fontSize)}b.restore();b.clip();b.beginPath();delete this.pendingTextPaths}},setCharSpacing:function(a){this.current.charSpacing=a},setWordSpacing:function(a){this.current.wordSpacing=a},setHScale:function(a){this.current.textHScale=a/100},setLeading:function(a){this.current.leading=-a},setFont:function(a,
b){var c=this.commonObjs.get(a),d=this.current;c||k("Can't find font for "+a);d.fontMatrix=c.fontMatrix?c.fontMatrix:l;(0===d.fontMatrix[0]||0===d.fontMatrix[3])&&m("Invalid font matrix for font "+a);0>b?(b=-b,d.fontDirection=-1):d.fontDirection=1;this.current.font=c;this.current.fontSize=b;if(!c.isType3Font){var d=c.black?c.bold?"900":"bold":c.bold?"bold":"normal",e=c.italic?"italic":"normal",c='"'+(c.loadedName||"sans-serif")+'", '+c.fallbackName,f=16>b?16:100<b?100:b;this.current.fontSizeScale=
b/f;this.ctx.font=e+" "+d+" "+f+"px "+c}},setTextRenderingMode:function(a){this.current.textRenderingMode=a},setTextRise:function(a){this.current.textRise=a},moveText:function(a,b){this.current.x=this.current.lineX+=a;this.current.y=this.current.lineY+=b},setLeadingMoveText:function(a,b){this.setLeading(-b);this.moveText(a,b)},setTextMatrix:function(a,b,c,d,e,f){this.current.textMatrix=[a,b,c,d,e,f];this.current.textMatrixScale=Math.sqrt(a*a+b*b);this.current.x=this.current.lineX=0;this.current.y=
this.current.lineY=0},nextLine:function(){this.moveText(0,this.current.leading)},paintChar:function(a,b,c){var d=this.ctx,e=this.current,f=e.font,g=e.textRenderingMode,e=e.fontSize/e.fontSizeScale,h=g&o.FILL_STROKE_MASK,g=!!(g&o.ADD_TO_PATH_FLAG),i;if(f.disableFontFace||g)i=f.getPathGenerator(this.commonObjs,a);f.disableFontFace?(d.save(),d.translate(b,c),d.beginPath(),i(d,e),(h===o.FILL||h===o.FILL_STROKE)&&d.fill(),(h===o.STROKE||h===o.FILL_STROKE)&&d.stroke(),d.restore()):((h===o.FILL||h===o.FILL_STROKE)&&
d.fillText(a,b,c),(h===o.STROKE||h===o.FILL_STROKE)&&d.strokeText(a,b,c));g&&(this.pendingTextPaths||(this.pendingTextPaths=[])).push({transform:d.mozCurrentTransform,x:b,y:c,fontSize:e,addToPath:i})},get isFontSubpixelAAEnabled(){var a=document.createElement("canvas").getContext("2d");a.scale(1.5,1);a.fillText("I",0,10);for(var a=a.getImageData(0,0,10,10).data,b=!1,c=3;c<a.length;c+=4)if(0<a[c]&&255>a[c]){b=!0;break}return n(this,"isFontSubpixelAAEnabled",b)},showText:function(a){var b=this.current,
c=b.font;if(c.isType3Font)return this.showType3Text(a);var d=b.fontSize;if(0!==d){var e=this.ctx,f=b.fontSizeScale,g=b.charSpacing,h=b.wordSpacing,i=b.fontDirection,j=b.textHScale*i,k=a.length,l=c.vertical,m=l?1:-1,n=c.defaultVMetrics,p=d*b.fontMatrix[0],r=b.textRenderingMode===o.FILL&&!c.disableFontFace;e.save();e.transform.apply(e,b.textMatrix);e.translate(b.x,b.y+b.textRise);0<i?e.scale(j,-1):e.scale(j,1);var q=b.lineWidth,v=b.textMatrixScale;if(0===v||0===q){if(v=b.textRenderingMode&o.FILL_STROKE_MASK,
v===o.STROKE||v===o.FILL_STROKE)this.cachedGetSinglePixelWidth=null,q=0.65*this.getSinglePixelWidth()}else q/=v;1!==f&&(e.scale(f,f),q/=f);e.lineWidth=q;for(v=q=0;v<k;++v){var u=a[v];if(t(u))q+=m*u*d/1E3;else{var w=!1,x=(u.isSpace?h:0)+g,z=u.fontChar,A=u.accent,y,B=u.width;if(l){var C;y=u.vmetric||n;C=u.vmetric?y[1]:0.5*B;C=-C*p;u=y[2]*p;B=y?-y[0]:B;y=C/f;u=(q+u)/f}else y=q/f,u=0;c.remeasure&&0<B&&(C=1E3*e.measureText(z).width/d*f,B<C&&this.isFontSubpixelAAEnabled?(C=B/C,w=!0,e.save(),e.scale(C,1),
y/=C):B!==C&&(y+=(B-C)/2E3*d/f));r&&!A?e.fillText(z,y,u):(this.paintChar(z,y,u),A&&(z=y+A.offset.x/f,y=u-A.offset.y/f,this.paintChar(A.fontChar,z,y)));q+=B*p+x*i;w&&e.restore()}}l?b.y-=q*j:b.x+=q*j;e.restore()}},showType3Text:function(a){var b=this.ctx,d=this.current,e=d.font,f=d.fontSize,g=d.fontDirection,h=e.vertical?1:-1,i=d.charSpacing,j=d.wordSpacing,k=d.textHScale*g,n=d.fontMatrix||l,p=a.length,q;if(!(d.textRenderingMode===o.INVISIBLE||0===f)){this.cachedGetSinglePixelWidth=null;b.save();b.transform.apply(b,
d.textMatrix);b.translate(d.x,d.y);b.scale(k,g);for(g=0;g<p;++g)if(q=a[g],t(q))q=h*q*f/1E3,this.ctx.translate(q,0),d.x+=q*k;else{var r=(q.isSpace?j:0)+i,u=e.charProcOperatorList[q.operatorListId];u?(this.processingType3=q,this.save(),b.scale(f,f),b.transform.apply(b,n),this.executeOperatorList(u),this.restore(),q=c.applyTransform([q.width,0],n)[0]*f+r,b.translate(q,0),d.x+=q*k):m('Type3 character "'+q.operatorListId+'" is not available')}b.restore();this.processingType3=null}},setCharWidth:function(){},
setCharWidthAndBounds:function(a,b,c,d,e,f){this.ctx.rect(c,d,e-c,f-d);this.clip();this.endPath()},getColorN_Pattern:function(a){if("TilingPattern"===a[0])var b=a[1],c=this.baseTransform||this.ctx.mozCurrentTransform.slice(),e=this,a=new q(a,b,this.ctx,{createCanvasGraphics:function(a){return new d(a,e.commonObjs,e.objs)}},c);else a=x(a);return a},setStrokeColorN:function(){this.current.strokeColor=this.getColorN_Pattern(arguments)},setFillColorN:function(){this.current.fillColor=this.getColorN_Pattern(arguments);
this.current.patternFill=!0},setStrokeRGBColor:function(a,b,d){a=c.makeCssRgb(a,b,d);this.ctx.strokeStyle=a;this.current.strokeColor=a},setFillRGBColor:function(a,b,d){a=c.makeCssRgb(a,b,d);this.ctx.fillStyle=a;this.current.fillColor=a;this.current.patternFill=!1},shadingFill:function(a){var b=this.ctx;this.save();a=x(a);b.fillStyle=a.getPattern(b,this,!0);var d=b.mozCurrentTransformInverse;if(d){var b=b.canvas,e=b.width,f=b.height,b=c.applyTransform([0,0],d),a=c.applyTransform([0,f],d),g=c.applyTransform([e,
0],d),h=c.applyTransform([e,f],d),d=Math.min(b[0],a[0],g[0],h[0]),e=Math.min(b[1],a[1],g[1],h[1]),f=Math.max(b[0],a[0],g[0],h[0]),b=Math.max(b[1],a[1],g[1],h[1]);this.ctx.fillRect(d,e,f-d,b-e)}else this.ctx.fillRect(-1E10,-1E10,2E10,2E10);this.restore()},beginInlineImage:function(){k("Should not call beginInlineImage")},beginImageData:function(){k("Should not call beginImageData")},paintFormXObjectBegin:function(a,b){this.save();this.baseTransformStack.push(this.baseTransform);i(a)&&6===a.length&&
this.transform.apply(this,a);this.baseTransform=this.ctx.mozCurrentTransform;i(b)&&4===b.length&&(this.ctx.rect(b[0],b[1],b[2]-b[0],b[3]-b[1]),this.clip(),this.endPath())},paintFormXObjectEnd:function(){this.restore();this.baseTransform=this.baseTransformStack.pop()},beginGroup:function(a){this.save();var b=this.ctx;a.isolated||C("TODO: Support non-isolated groups.");a.knockout&&m("Knockout groups not supported.");var d=b.mozCurrentTransform;a.matrix&&b.transform.apply(b,a.matrix);y(a.bbox,"Bounding box is required.");
var e=c.getAxialAlignedBoundingBox(a.bbox,b.mozCurrentTransform),e=c.intersect(e,[0,0,b.canvas.width,b.canvas.height])||[0,0,0,0],f=Math.floor(e[0]),g=Math.floor(e[1]),h=Math.max(Math.ceil(e[2])-f,1),i=Math.max(Math.ceil(e[3])-g,1),j=e=1;4096<h&&(e=h/4096,h=4096);4096<i&&(j=i/4096,i=4096);var k="groupAt"+this.groupLevel;a.smask&&(k+="_smask_"+this.smaskCounter++%2);h=this.cachedCanvases.getCanvas(k,h,i,!0);i=h.context;i.scale(1/e,1/j);i.translate(-f,-g);i.transform.apply(i,d);a.smask?this.smaskStack.push({canvas:h.canvas,
context:i,offsetX:f,offsetY:g,scaleX:e,scaleY:j,subtype:a.smask.subtype,backdrop:a.smask.backdrop,transferMap:a.smask.transferMap||null}):(b.setTransform(1,0,0,1,0,0),b.translate(f,g),b.scale(e,j));v(b,i);this.ctx=i;this.setGState([["BM","Normal"],["ca",1],["CA",1]]);this.groupStack.push(b);this.groupLevel++},endGroup:function(a){this.groupLevel--;var b=this.ctx;this.ctx=this.groupStack.pop();void 0!==this.ctx.imageSmoothingEnabled?this.ctx.imageSmoothingEnabled=!1:this.ctx.mozImageSmoothingEnabled=
!1;a.smask?this.tempSMask=this.smaskStack.pop():this.ctx.drawImage(b.canvas,0,0);this.restore()},beginAnnotations:function(){this.save();this.current=new w;this.baseTransform&&this.ctx.setTransform.apply(this.ctx,this.baseTransform)},endAnnotations:function(){this.restore()},beginAnnotation:function(a,b,c){this.save();i(a)&&4===a.length&&(this.ctx.rect(a[0],a[1],a[2]-a[0],a[3]-a[1]),this.clip(),this.endPath());this.transform.apply(this,b);this.transform.apply(this,c)},endAnnotation:function(){this.restore()},
paintJpegXObject:function(a,b,c){var d=this.objs.get(a);if(d){this.save();var e=this.ctx;e.scale(1/b,-1/c);e.drawImage(d,0,0,d.width,d.height,0,-c,b,c);this.imageLayer&&(d=e.mozCurrentTransformInverse,e=this.getCanvasPosition(0,0),this.imageLayer.appendImage({objId:a,left:e[0],top:e[1],width:b/d[0],height:c/d[3]}));this.restore()}else m("Dependent image isn't ready yet")},paintImageMaskXObject:function(a){var b=this.ctx,c=a.width,d=a.height,e=this.current.fillColor,f=this.current.patternFill,g=this.processingType3;
g&&void 0===g.compiled&&(g.compiled=1E3>=c&&1E3>=d?p({data:a.data,width:c,height:d}):null);g&&g.compiled?g.compiled(b):(b=this.cachedCanvases.getCanvas("maskCanvas",c,d),g=b.context,g.save(),u(g,a),g.globalCompositeOperation="source-in",g.fillStyle=f?e.getPattern(g,this):e,g.fillRect(0,0,c,d),g.restore(),this.paintInlineImageXObject(b.canvas))},paintImageMaskXObjectRepeat:function(a,b,c,d){var e=a.width,f=a.height,g=this.current.fillColor,h=this.current.patternFill,i=this.cachedCanvases.getCanvas("maskCanvas",
e,f),j=i.context;j.save();u(j,a);j.globalCompositeOperation="source-in";j.fillStyle=h?g.getPattern(j,this):g;j.fillRect(0,0,e,f);j.restore();a=this.ctx;g=0;for(h=d.length;g<h;g+=2)a.save(),a.transform(b,0,0,c,d[g],d[g+1]),a.scale(1,-1),a.drawImage(i.canvas,0,0,e,f,0,-1,1,1),a.restore()},paintImageMaskXObjectGroup:function(a){for(var b=this.ctx,c=this.current.fillColor,d=this.current.patternFill,e=0,f=a.length;e<f;e++){var g=a[e],h=g.width,i=g.height,j=this.cachedCanvases.getCanvas("maskCanvas",h,
i),k=j.context;k.save();u(k,g);k.globalCompositeOperation="source-in";k.fillStyle=d?c.getPattern(k,this):c;k.fillRect(0,0,h,i);k.restore();b.save();b.transform.apply(b,g.transform);b.scale(1,-1);b.drawImage(j.canvas,0,0,h,i,0,-1,1,1);b.restore()}},paintImageXObject:function(a){(a=this.objs.get(a))?this.paintInlineImageXObject(a):m("Dependent image isn't ready yet")},paintImageXObjectRepeat:function(a,b,c,d){if(a=this.objs.get(a)){for(var e=a.width,f=a.height,g=[],h=0,i=d.length;h<i;h+=2)g.push({transform:[b,
0,0,c,d[h],d[h+1]],x:0,y:0,w:e,h:f});this.paintInlineImageXObjectGroup(a,g)}else m("Dependent image isn't ready yet")},paintInlineImageXObject:function(a){var b=a.width,c=a.height,d=this.ctx;this.save();d.scale(1/b,-1/c);var e=d.mozCurrentTransformInverse,f=e[0],h=e[1],f=Math.max(Math.sqrt(f*f+h*h),1),h=e[2],i=e[3],h=Math.max(Math.sqrt(h*h+i*i),1),k;if(a instanceof HTMLElement||!a.data)i=a;else{k=this.cachedCanvases.getCanvas("inlineImage",b,c);var l=k.context;g(l,a);i=k.canvas}for(var m=b,n=c,p=
"prescale1";2<f&&1<m||2<h&&1<n;){var o=m,q=n;2<f&&1<m&&(o=Math.ceil(m/2),f/=m/o);2<h&&1<n&&(q=Math.ceil(n/2),h/=n/q);k=this.cachedCanvases.getCanvas(p,o,q);l=k.context;l.clearRect(0,0,o,q);l.drawImage(i,0,0,m,n,0,0,o,q);i=k.canvas;m=o;n=q;p="prescale1"===p?"prescale2":"prescale1"}d.drawImage(i,0,0,m,n,0,-c,b,c);this.imageLayer&&(d=this.getCanvasPosition(0,-c),this.imageLayer.appendImage({imgData:a,left:d[0],top:d[1],width:b/e[0],height:c/e[3]}));this.restore()},paintInlineImageXObjectGroup:function(a,
b){var c=this.ctx,d=a.width,e=a.height,f=this.cachedCanvases.getCanvas("inlineImage",d,e);g(f.context,a);for(var h=0,i=b.length;h<i;h++){var k=b[h];c.save();c.transform.apply(c,k.transform);c.scale(1,-1);c.drawImage(f.canvas,k.x,k.y,k.w,k.h,0,-1,1,1);this.imageLayer&&(k=this.getCanvasPosition(k.x,k.y),this.imageLayer.appendImage({imgData:a,left:k[0],top:k[1],width:d,height:e}));c.restore()}},paintSolidColorImageMask:function(){this.ctx.fillRect(0,0,1,1)},paintXObject:function(){m("Unsupported 'paintXObject' command.")},
markPoint:function(){},markPointProps:function(){},beginMarkedContent:function(){},beginMarkedContentProps:function(){},endMarkedContent:function(){},beginCompat:function(){},endCompat:function(){},consumePath:function(){var a=this.ctx;this.pendingClip&&(this.pendingClip===R?void 0!==a.mozFillRule?(a.mozFillRule="evenodd",a.clip(),a.mozFillRule="nonzero"):a.clip("evenodd"):a.clip(),this.pendingClip=null);a.beginPath()},getSinglePixelWidth:function(){if(null===this.cachedGetSinglePixelWidth){var a=
this.ctx.mozCurrentTransformInverse;this.cachedGetSinglePixelWidth=Math.sqrt(Math.max(a[0]*a[0]+a[1]*a[1],a[2]*a[2]+a[3]*a[3]))}return this.cachedGetSinglePixelWidth},getCanvasPosition:function(a,b){var c=this.ctx.mozCurrentTransform;return[c[0]*a+c[2]*b+c[4],c[1]*a+c[3]*b+c[5]]}};for(var D in r)d.prototype[r[D]]=d.prototype[D];return d}();d.CanvasGraphics=g;d.createScratchCanvas=E});(function(d,g){g(d.pdfjsDisplayAPI={},d.pdfjsSharedUtil,d.pdfjsDisplayFontLoader,d.pdfjsDisplayCanvas,d.pdfjsSharedGlobal)})(this,
function(d,g,A,v,E){function G(a,b,c,d){if(a.destroyed)return Promise.reject(Error("Worker was destroyed"));b.disableAutoFetch=j.disableAutoFetch;b.disableStream=j.disableStream;b.chunkedViewerLoading=!!c;c&&(b.length=c.length,b.initialData=c.initialData);return a.messageHandler.sendWithPromise("GetDocRequest",{docId:d,source:b,disableRange:j.disableRange,maxImageSize:j.maxImageSize,cMapUrl:j.cMapUrl,cMapPacked:j.cMapPacked,disableFontFace:j.disableFontFace,disableCreateObjectURL:j.disableCreateObjectURL,
verbosity:j.verbosity}).then(function(b){if(a.destroyed)throw Error("Worker was destroyed");return b})}var p=g.InvalidPDFException,l=g.MessageHandler,I=g.MissingPDFException,B=g.PasswordResponses,r=g.PasswordException,o=g.StatTimer,e=g.UnexpectedResponseException,c=g.UnknownErrorException,y=g.Util,C=g.createPromiseCapability,t=g.combineUrl,i=g.error,k=g.deprecated,n=g.info,m=g.isArrayBuffer,q=g.loadJpegStream,x=g.stringToBytes,a=g.warn,b=A.FontFaceObject,h=A.FontLoader,w=v.CanvasGraphics,f=v.createScratchCanvas,
j=E.PDFJS,u=E.globalScope,g=!1;"undefined"!==typeof module&&module.require&&(j.disableWorker=!0,"undefined"===typeof require.ensure&&(require.ensure=require("node-ensure")),g=!0);"undefined"!==typeof __webpack_require__&&(j.workerSrc=require("entry?name=[hash]-worker.js!./pdf.worker.js"),g=!0);var H=g&&function(a){require.ensure([],function(){require("./pdf.worker.js");a()})};j.maxImageSize=void 0===j.maxImageSize?-1:j.maxImageSize;j.cMapUrl=void 0===j.cMapUrl?null:j.cMapUrl;j.cMapPacked=void 0===
j.cMapPacked?!1:j.cMapPacked;j.disableFontFace=void 0===j.disableFontFace?!1:j.disableFontFace;j.imageResourcesPath=void 0===j.imageResourcesPath?"":j.imageResourcesPath;j.disableWorker=void 0===j.disableWorker?!1:j.disableWorker;j.workerSrc=void 0===j.workerSrc?null:j.workerSrc;j.disableRange=void 0===j.disableRange?!1:j.disableRange;j.disableStream=void 0===j.disableStream?!1:j.disableStream;j.disableAutoFetch=void 0===j.disableAutoFetch?!1:j.disableAutoFetch;j.pdfBug=void 0===j.pdfBug?!1:j.pdfBug;
j.postMessageTransfers=void 0===j.postMessageTransfers?!0:j.postMessageTransfers;j.disableCreateObjectURL=void 0===j.disableCreateObjectURL?!1:j.disableCreateObjectURL;j.disableWebGL=void 0===j.disableWebGL?!0:j.disableWebGL;j.disableFullscreen=void 0===j.disableFullscreen?!1:j.disableFullscreen;j.useOnlyCssZoom=void 0===j.useOnlyCssZoom?!1:j.useOnlyCssZoom;j.verbosity=void 0===j.verbosity?j.VERBOSITY_LEVELS.warnings:j.verbosity;j.maxCanvasPixels=void 0===j.maxCanvasPixels?16777216:j.maxCanvasPixels;
j.openExternalLinksInNewWindow=void 0===j.openExternalLinksInNewWindow?!1:j.openExternalLinksInNewWindow;j.externalLinkTarget=void 0===j.externalLinkTarget?j.LinkTarget.NONE:j.externalLinkTarget;j.externalLinkRel=void 0===j.externalLinkRel?"noreferrer":j.externalLinkRel;j.isEvalSupported=void 0===j.isEvalSupported?!0:j.isEvalSupported;j.getDocument=function(a,b,c,d){var e=new M;1<arguments.length&&k("getDocument is called with pdfDataRangeTransport, passwordCallback or progressCallback argument");
b&&(b instanceof P||(b=Object.create(b),b.length=a.length,b.initialData=a.initialData,b.abort||(b.abort=function(){})),a=Object.create(a),a.range=b);e.onPassword=c||null;e.onProgress=d||null;var f;"string"===typeof a?f={url:a}:m(a)?f={data:a}:a instanceof P?f={range:a}:("object"!==typeof a&&i("Invalid parameter in getDocument, need either Uint8Array, string or a parameter object"),!a.url&&!a.data&&!a.range&&i("Invalid parameter object: need either .data, .range or .url"),f=a);var g={},h=null,j=null,
n;for(n in f)if("url"===n&&"undefined"!==typeof window)g[n]=t(window.location.href,f[n]);else if("range"===n)h=f[n];else if("worker"===n)j=f[n];else if("data"===n&&!(f[n]instanceof Uint8Array)){var o=f[n];"string"===typeof o?g[n]=x(o):"object"===typeof o&&null!==o&&!isNaN(o.length)?g[n]=new Uint8Array(o):m(o)?g[n]=new Uint8Array(o):i("Invalid PDF binary data: either typed array, string or array-like object is expected in the data property.")}else g[n]=f[n];g.rangeChunkSize=g.rangeChunkSize||65536;
j||(j=new O,e._worker=j);var p=e.docId;j.promise.then(function(){if(e.destroyed)throw Error("Loading aborted");return G(j,g,h,p).then(function(a){if(e.destroyed)throw Error("Loading aborted");a=new l(p,a,j.port);a.send("Ready",null);a=new R(a,e,h);e._transport=a})}).catch(e._capability.reject);return e};var M=function(){function a(){this._capability=C();this._worker=this._transport=null;this.docId="d"+b++;this.destroyed=!1;this.onUnsupportedFeature=this.onProgress=this.onPassword=null}var b=0;a.prototype=
{get promise(){return this._capability.promise},destroy:function(){this.destroyed=!0;return(!this._transport?Promise.resolve():this._transport.destroy()).then(function(){this._transport=null;this._worker&&(this._worker.destroy(),this._worker=null)}.bind(this))},then:function(a,b){return this.promise.then.apply(this.promise,arguments)}};return a}(),P=function(){function a(b,c){this.length=b;this.initialData=c;this._rangeListeners=[];this._progressListeners=[];this._progressiveReadListeners=[];this._readyCapability=
C()}a.prototype={addRangeListener:function(a){this._rangeListeners.push(a)},addProgressListener:function(a){this._progressListeners.push(a)},addProgressiveReadListener:function(a){this._progressiveReadListeners.push(a)},onDataRange:function(a,b){for(var c=this._rangeListeners,d=0,e=c.length;d<e;++d)c[d](a,b)},onDataProgress:function(a){this._readyCapability.promise.then(function(){for(var b=this._progressListeners,c=0,d=b.length;c<d;++c)b[c](a)}.bind(this))},onDataProgressiveRead:function(a){this._readyCapability.promise.then(function(){for(var b=
this._progressiveReadListeners,c=0,d=b.length;c<d;++c)b[c](a)}.bind(this))},transportReady:function(){this._readyCapability.resolve()},requestDataRange:function(){throw Error("Abstract method PDFDataRangeTransport.requestDataRange");},abort:function(){}};return a}();j.PDFDataRangeTransport=P;var z=function(){function a(b,c,d){this.pdfInfo=b;this.transport=c;this.loadingTask=d}a.prototype={get numPages(){return this.pdfInfo.numPages},get fingerprint(){return this.pdfInfo.fingerprint},getPage:function(a){return this.transport.getPage(a)},
getPageIndex:function(a){return this.transport.getPageIndex(a)},getDestinations:function(){return this.transport.getDestinations()},getDestination:function(a){return this.transport.getDestination(a)},getAttachments:function(){return this.transport.getAttachments()},getJavaScript:function(){return this.transport.getJavaScript()},getOutline:function(){return this.transport.getOutline()},getMetadata:function(){return this.transport.getMetadata()},getData:function(){return this.transport.getData()},getDownloadInfo:function(){return this.transport.downloadInfoCapability.promise},
getStats:function(){return this.transport.getStats()},cleanup:function(){this.transport.startCleanup()},destroy:function(){return this.loadingTask.destroy()}};return a}(),Q=function(){function a(b,c,d){this.pageIndex=b;this.pageInfo=c;this.transport=d;this.stats=new o;this.stats.enabled=!!u.PDFJS.enableStats;this.commonObjs=d.commonObjs;this.objs=new D;this.pendingCleanup=this.cleanupAfterRender=!1;this.intentStates={};this.destroyed=!1}a.prototype={get pageNumber(){return this.pageIndex+1},get rotate(){return this.pageInfo.rotate},
get ref(){return this.pageInfo.ref},get view(){return this.pageInfo.view},getViewport:function(a,b){2>arguments.length&&(b=this.rotate);return new j.PageViewport(this.view,a,b,0,0)},getAnnotations:function(a){a=a&&a.intent||null;if(!this.annotationsPromise||this.annotationsIntent!==a)this.annotationsPromise=this.transport.getAnnotations(this.pageIndex,a),this.annotationsIntent=a;return this.annotationsPromise},render:function(a){function b(a){var d=e.renderTasks.indexOf(f);0<=d&&e.renderTasks.splice(d,
1);g.cleanupAfterRender&&(g.pendingCleanup=!0);g._tryCleanup();a?f.capability.reject(a):f.capability.resolve();c.timeEnd("Rendering");c.timeEnd("Overall")}var c=this.stats;c.time("Overall");this.pendingCleanup=!1;var d="print"===a.intent?"print":"display";this.intentStates[d]||(this.intentStates[d]={});var e=this.intentStates[d];e.displayReadyCapability||(e.receivingOperatorList=!0,e.displayReadyCapability=C(),e.operatorList={fnArray:[],argsArray:[],lastChunk:!1},this.stats.time("Page Request"),this.transport.messageHandler.send("RenderPageRequest",
{pageIndex:this.pageNumber-1,intent:d}));var f=new F(b,a,this.objs,this.commonObjs,e.operatorList,this.pageNumber);f.useRequestAnimationFrame="print"!==d;e.renderTasks||(e.renderTasks=[]);e.renderTasks.push(f);d=f.task;a.continueCallback&&(k("render is used with continueCallback parameter"),d.onContinue=a.continueCallback);var g=this;e.displayReadyCapability.promise.then(function(a){g.pendingCleanup?b():(c.time("Rendering"),f.initalizeGraphics(a),f.operatorListChanged())},function(a){b(a)});return d},
getOperatorList:function(){function a(){b.operatorList.lastChunk&&b.opListReadCapability.resolve(b.operatorList)}this.intentStates.oplist||(this.intentStates.oplist={});var b=this.intentStates.oplist;if(!b.opListReadCapability){var c={};c.operatorListChanged=a;b.receivingOperatorList=!0;b.opListReadCapability=C();b.renderTasks=[];b.renderTasks.push(c);b.operatorList={fnArray:[],argsArray:[],lastChunk:!1};this.transport.messageHandler.send("RenderPageRequest",{pageIndex:this.pageIndex,intent:"oplist"})}return b.opListReadCapability.promise},
getTextContent:function(a){return this.transport.messageHandler.sendWithPromise("GetTextContent",{pageIndex:this.pageNumber-1,normalizeWhitespace:a&&a.normalizeWhitespace||!1})},_destroy:function(){this.destroyed=!0;this.transport.pageCache[this.pageIndex]=null;var a=[];Object.keys(this.intentStates).forEach(function(b){this.intentStates[b].renderTasks.forEach(function(b){var c=b.capability.promise.catch(function(){});a.push(c);b.cancel()})},this);this.objs.clear();this.annotationsPromise=null;this.pendingCleanup=
!1;return Promise.all(a)},destroy:function(){k("page destroy method, use cleanup() instead");this.cleanup()},cleanup:function(){this.pendingCleanup=!0;this._tryCleanup()},_tryCleanup:function(){this.pendingCleanup&&!Object.keys(this.intentStates).some(function(a){a=this.intentStates[a];return 0!==a.renderTasks.length||a.receivingOperatorList},this)&&(Object.keys(this.intentStates).forEach(function(a){delete this.intentStates[a]},this),this.objs.clear(),this.annotationsPromise=null,this.pendingCleanup=
!1)},_startRenderPage:function(a,b){var c=this.intentStates[b];c.displayReadyCapability&&c.displayReadyCapability.resolve(a)},_renderPageChunk:function(a,b){var c=this.intentStates[b],d,e;for(d=0,e=a.length;d<e;d++)c.operatorList.fnArray.push(a.fnArray[d]),c.operatorList.argsArray.push(a.argsArray[d]);c.operatorList.lastChunk=a.lastChunk;for(d=0;d<c.renderTasks.length;d++)c.renderTasks[d].operatorListChanged();a.lastChunk&&(c.receivingOperatorList=!1,this._tryCleanup())}};return a}(),O=function(){function b(){j.fakeWorkerFilesLoadedCapability||
(j.fakeWorkerFilesLoadedCapability=C(),(H||function(a){y.loadScript(j.workerSrc,a)})(function(){j.fakeWorkerFilesLoadedCapability.resolve()}));return j.fakeWorkerFilesLoadedCapability.promise}function c(a){this.name=a;this.destroyed=!1;this._readyCapability=C();this._messageHandler=this._webWorker=this._port=null;this._initialize()}var d=0;c.prototype={get promise(){return this._readyCapability.promise},get port(){return this._port},get messageHandler(){return this._messageHandler},_initialize:function(){if(!u.PDFJS.disableWorker&&
"undefined"!==typeof Worker){var a=j.workerSrc;a||i("No PDFJS.workerSrc specified");try{var b=new Worker(a),c=new l("main","worker",b);c.on("test",function(a){this.destroyed?(this._readyCapability.reject(Error("Worker was destroyed")),c.destroy(),b.terminate()):a&&a.supportTypedArray?(this._messageHandler=c,this._webWorker=this._port=b,a.supportTransfers||(j.postMessageTransfers=!1),this._readyCapability.resolve()):(this._setupFakeWorker(),c.destroy(),b.terminate())}.bind(this));c.on("console_log",
function(a){console.log.apply(console,a)});c.on("console_error",function(a){console.error.apply(console,a)});c.on("ready",function(){if(this.destroyed)this._readyCapability.reject(Error("Worker was destroyed")),c.destroy(),b.terminate();else try{d()}catch(a){this._setupFakeWorker()}}.bind(this));var d=function(){var a=new Uint8Array([j.postMessageTransfers?255:0]);try{c.send("test",a,[a.buffer])}catch(b){n("Cannot use postMessage transfers"),a[0]=0,c.send("test",a)}};d();return}catch(e){n("The worker has been disabled.")}}this._setupFakeWorker()},
_setupFakeWorker:function(){u.PDFJS.disableWorker||(a("Setting up fake worker."),u.PDFJS.disableWorker=!0);b().then(function(){if(this.destroyed)this._readyCapability.reject(Error("Worker was destroyed"));else{var a={_listeners:[],postMessage:function(a){var b={data:a};this._listeners.forEach(function(a){a.call(this,b)},this)},addEventListener:function(a,b){this._listeners.push(b)},removeEventListener:function(a,b){this._listeners.splice(this._listeners.indexOf(b),1)},terminate:function(){}};this._port=
a;var b="fake"+d++,c=new l(b+"_worker",b,a);j.WorkerMessageHandler.setup(c,a);this._messageHandler=new l(b,b+"_worker",a);this._readyCapability.resolve()}}.bind(this))},destroy:function(){this.destroyed=!0;this._webWorker&&(this._webWorker.terminate(),this._webWorker=null);this._port=null;this._messageHandler&&(this._messageHandler.destroy(),this._messageHandler=null)}};return c}();j.PDFWorker=O;var R=function(){function d(a,b,c){this.messageHandler=a;this.loadingTask=b;this.pdfDataRangeTransport=
c;this.commonObjs=new D;this.fontLoader=new h(b.docId);this.destroyed=!1;this.destroyCapability=null;this.pageCache=[];this.pagePromises=[];this.downloadInfoCapability=C();this.setupMessageHandler()}d.prototype={destroy:function(){if(this.destroyCapability)return this.destroyCapability.promise;this.destroyed=!0;this.destroyCapability=C();var a=[];this.pageCache.forEach(function(b){b&&a.push(b._destroy())});this.pageCache=[];this.pagePromises=[];var b=this,c=this.messageHandler.sendWithPromise("Terminate",
null);a.push(c);Promise.all(a).then(function(){b.fontLoader.clear();b.pdfDataRangeTransport&&(b.pdfDataRangeTransport.abort(),b.pdfDataRangeTransport=null);b.messageHandler&&(b.messageHandler.destroy(),b.messageHandler=null);b.destroyCapability.resolve()},this.destroyCapability.reject);return this.destroyCapability.promise},setupMessageHandler:function(){function d(a){g.send("UpdatePassword",a)}var g=this.messageHandler,h=this.pdfDataRangeTransport;h&&(h.addRangeListener(function(a,b){g.send("OnDataRange",
{begin:a,chunk:b})}),h.addProgressListener(function(a){g.send("OnDataProgress",{loaded:a})}),h.addProgressiveReadListener(function(a){g.send("OnDataRange",{chunk:a})}),g.on("RequestDataRange",function(a){h.requestDataRange(a.begin,a.end)},this));g.on("GetDoc",function(a){var b=a.pdfInfo;this.numPages=a.pdfInfo.numPages;a=this.loadingTask;this.pdfDocument=b=new z(b,this,a);a._capability.resolve(b)},this);g.on("NeedPassword",function(a){var b=this.loadingTask;if(b.onPassword)return b.onPassword(d,B.NEED_PASSWORD);
b._capability.reject(new r(a.message,a.code))},this);g.on("IncorrectPassword",function(a){var b=this.loadingTask;if(b.onPassword)return b.onPassword(d,B.INCORRECT_PASSWORD);b._capability.reject(new r(a.message,a.code))},this);g.on("InvalidPDF",function(a){this.loadingTask._capability.reject(new p(a.message))},this);g.on("MissingPDF",function(a){this.loadingTask._capability.reject(new I(a.message))},this);g.on("UnexpectedResponse",function(a){this.loadingTask._capability.reject(new e(a.message,a.status))},
this);g.on("UnknownError",function(a){this.loadingTask._capability.reject(new c(a.message,a.details))},this);g.on("DataLoaded",function(a){this.downloadInfoCapability.resolve(a)},this);g.on("PDFManagerReady",function(){this.pdfDataRangeTransport&&this.pdfDataRangeTransport.transportReady()},this);g.on("StartRenderPage",function(a){if(!this.destroyed){var b=this.pageCache[a.pageIndex];b.stats.timeEnd("Page Request");b._startRenderPage(a.transparency,a.intent)}},this);g.on("RenderPageChunk",function(a){this.destroyed||
this.pageCache[a.pageIndex]._renderPageChunk(a.operatorList,a.intent)},this);g.on("commonobj",function(c){if(!this.destroyed){var d=c[0],e=c[1];if(!this.commonObjs.hasData(d))switch(e){case "Font":var c=c[2],f;if("error"in c){var g=c.error;a("Error during font loading: "+g);this.commonObjs.resolve(d,g);break}else f=new b(c);this.fontLoader.bind([f],function(){this.commonObjs.resolve(d,f)}.bind(this));break;case "FontPath":this.commonObjs.resolve(d,c[2]);break;default:g("Got unknown common object type "+
e)}}},this);g.on("obj",function(a){if(!this.destroyed){var b=a[0],c=a[2],d=this.pageCache[a[1]];if(!d.objs.hasData(b))switch(c){case "JpegStream":a=a[3];q(b,a,d.objs);break;case "Image":a=a[3];d.objs.resolve(b,a);a&&"data"in a&&8E6<a.data.length&&(d.cleanupAfterRender=!0);break;default:i("Got unknown object type "+c)}}},this);g.on("DocProgress",function(a){if(!this.destroyed){var b=this.loadingTask;if(b.onProgress)b.onProgress({loaded:a.loaded,total:a.total})}},this);g.on("PageError",function(a){if(!this.destroyed){var b=
this.pageCache[a.pageNum-1].intentStates[a.intent];b.displayReadyCapability?b.displayReadyCapability.reject(a.error):i(a.error)}},this);g.on("UnsupportedFeature",function(a){if(!this.destroyed){var a=a.featureId,b=this.loadingTask;if(b.onUnsupportedFeature)b.onUnsupportedFeature(a);j.UnsupportedManager.notify(a)}},this);g.on("JpegDecode",function(a){if(this.destroyed)return Promise.reject("Worker was terminated");var b=a[0],c=a[1];return 3!==c&&1!==c?Promise.reject(Error("Only 3 components or 1 component can be returned")):
new Promise(function(a,d){var e=new Image;e.onload=function(){var b=e.width,d=e.height,g=b*d,h=4*g,g=new Uint8Array(g*c),i=f(b,d).getContext("2d");i.drawImage(e,0,0);var i=i.getImageData(0,0,b,d).data,j,k;if(3===c)for(j=0,k=0;j<h;j+=4,k+=3)g[k]=i[j],g[k+1]=i[j+1],g[k+2]=i[j+2];else if(1===c)for(j=0,k=0;j<h;j+=4,k++)g[k]=i[j];a({data:g,width:b,height:d})};e.onerror=function(){d(Error("JpegDecode failed to load image"))};e.src=b})},this)},getData:function(){return this.messageHandler.sendWithPromise("GetData",
null)},getPage:function(a){if(0>=a||a>this.numPages||(a|0)!==a)return Promise.reject(Error("Invalid page request"));var b=a-1;if(b in this.pagePromises)return this.pagePromises[b];a=this.messageHandler.sendWithPromise("GetPage",{pageIndex:b}).then(function(a){if(this.destroyed)throw Error("Transport destroyed");a=new Q(b,a,this);return this.pageCache[b]=a}.bind(this));return this.pagePromises[b]=a},getPageIndex:function(a){return this.messageHandler.sendWithPromise("GetPageIndex",{ref:a})},getAnnotations:function(a,
b){return this.messageHandler.sendWithPromise("GetAnnotations",{pageIndex:a,intent:b})},getDestinations:function(){return this.messageHandler.sendWithPromise("GetDestinations",null)},getDestination:function(a){return this.messageHandler.sendWithPromise("GetDestination",{id:a})},getAttachments:function(){return this.messageHandler.sendWithPromise("GetAttachments",null)},getJavaScript:function(){return this.messageHandler.sendWithPromise("GetJavaScript",null)},getOutline:function(){return this.messageHandler.sendWithPromise("GetOutline",
null)},getMetadata:function(){return this.messageHandler.sendWithPromise("GetMetadata",null).then(function(a){return{info:a[0],metadata:a[1]?new j.Metadata(a[1]):null}})},getStats:function(){return this.messageHandler.sendWithPromise("GetStats",null)},startCleanup:function(){this.messageHandler.sendWithPromise("Cleanup",null).then(function(){for(var a=0,b=this.pageCache.length;a<b;a++){var c=this.pageCache[a];c&&c.cleanup()}this.commonObjs.clear();this.fontLoader.clear()}.bind(this))}};return d}(),
D=function(){function a(){this.objs={}}a.prototype={ensureObj:function(a){if(this.objs[a])return this.objs[a];var b={capability:C(),data:null,resolved:!1};return this.objs[a]=b},get:function(a,b){if(b)return this.ensureObj(a).capability.promise.then(b),null;var c=this.objs[a];(!c||!c.resolved)&&i("Requesting object that isn't resolved yet "+a);return c.data},resolve:function(a,b){var c=this.ensureObj(a);c.resolved=!0;c.data=b;c.capability.resolve(b)},isResolved:function(a){var b=this.objs;return b[a]?
b[a].resolved:!1},hasData:function(a){return this.isResolved(a)},getData:function(a){var b=this.objs;return!b[a]||!b[a].resolved?null:b[a].data},clear:function(){this.objs={}}};return a}(),s=function(){function a(b){this._internalRenderTask=b;this.onContinue=null}a.prototype={get promise(){return this._internalRenderTask.capability.promise},cancel:function(){this._internalRenderTask.cancel()},then:function(a,b){return this.promise.then.apply(this.promise,arguments)}};return a}(),F=function(){function a(b,
c,d,e,f,g){this.callback=b;this.params=c;this.objs=d;this.commonObjs=e;this.operatorListIdx=null;this.operatorList=f;this.pageNumber=g;this.running=!1;this.graphicsReadyCallback=null;this.cancelled=this.useRequestAnimationFrame=this.graphicsReady=!1;this.capability=C();this.task=new s(this);this._continueBound=this._continue.bind(this);this._scheduleNextBound=this._scheduleNext.bind(this);this._nextBound=this._next.bind(this)}a.prototype={initalizeGraphics:function(a){if(!this.cancelled){j.pdfBug&&
"StepperManager"in u&&u.StepperManager.enabled&&(this.stepper=u.StepperManager.create(this.pageNumber-1),this.stepper.init(this.operatorList),this.stepper.nextBreakPoint=this.stepper.getNextBreakPoint());var b=this.params;this.gfx=new w(b.canvasContext,this.commonObjs,this.objs,b.imageLayer);this.gfx.beginDrawing(b.transform,b.viewport,a);this.operatorListIdx=0;this.graphicsReady=!0;this.graphicsReadyCallback&&this.graphicsReadyCallback()}},cancel:function(){this.running=!1;this.cancelled=!0;this.callback("cancelled")},
operatorListChanged:function(){this.graphicsReady?(this.stepper&&this.stepper.updateOperatorList(this.operatorList),this.running||this._continue()):this.graphicsReadyCallback||(this.graphicsReadyCallback=this._continueBound)},_continue:function(){this.running=!0;this.cancelled||(this.task.onContinue?this.task.onContinue.call(this.task,this._scheduleNextBound):this._scheduleNext())},_scheduleNext:function(){this.useRequestAnimationFrame?window.requestAnimationFrame(this._nextBound):Promise.resolve(void 0).then(this._nextBound)},
_next:function(){this.cancelled||(this.operatorListIdx=this.gfx.executeOperatorList(this.operatorList,this.operatorListIdx,this._continueBound,this.stepper),this.operatorListIdx===this.operatorList.argsArray.length&&(this.running=!1,this.operatorList.lastChunk&&(this.gfx.endDrawing(),this.callback())))}};return a}();j.UnsupportedManager=function(){var a=[];return{listen:function(b){k("Global UnsupportedManager.listen is used:  use PDFDocumentLoadingTask.onUnsupportedFeature instead");a.push(b)},notify:function(b){for(var c=
0,d=a.length;c<d;c++)a[c](b)}}}();d.getDocument=j.getDocument;d.PDFDataRangeTransport=P;d.PDFDocumentProxy=z;d.PDFPageProxy=Q})}).call("undefined"===typeof window?this:window);!PDFJS.workerSrc&&"undefined"!==typeof document&&(PDFJS.workerSrc=function(){var d=document.currentScript.src;return d&&d.replace(/\.js$/i,".worker.js")}());
